# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/exchange/v1beta1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from injective.exchange.v1beta1 import exchange_pb2 as injective_dot_exchange_dot_v1beta1_dot_exchange__pb2
from injective.exchange.v1beta1 import genesis_pb2 as injective_dot_exchange_dot_v1beta1_dot_genesis__pb2
from injective.oracle.v1beta1 import oracle_pb2 as injective_dot_oracle_dot_v1beta1_dot_oracle__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&injective/exchange/v1beta1/query.proto\x12\x1ainjective.exchange.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a)injective/exchange/v1beta1/exchange.proto\x1a(injective/exchange/v1beta1/genesis.proto\x1a%injective/oracle/v1beta1/oracle.proto\x1a\x14gogoproto/gogo.proto\"6\n\nSubaccount\x12\x0e\n\x06trader\x18\x01 \x01(\t\x12\x18\n\x10subaccount_nonce\x18\x02 \x01(\r\"H\n\x1cQuerySubaccountOrdersRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\"\xaa\x01\n\x1dQuerySubaccountOrdersResponse\x12\x43\n\nbuy_orders\x18\x01 \x03(\x0b\x32/.injective.exchange.v1beta1.SubaccountOrderData\x12\x44\n\x0bsell_orders\x18\x02 \x03(\x0b\x32/.injective.exchange.v1beta1.SubaccountOrderData\"\x94\x01\n%SubaccountOrderbookMetadataWithMarket\x12I\n\x08metadata\x18\x01 \x01(\x0b\x32\x37.injective.exchange.v1beta1.SubaccountOrderbookMetadata\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\r\n\x05isBuy\x18\x03 \x01(\x08\"\x1c\n\x1aQueryExchangeParamsRequest\"W\n\x1bQueryExchangeParamsResponse\x12\x38\n\x06params\x18\x01 \x01(\x0b\x32\".injective.exchange.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\"y\n\x1eQuerySubaccountDepositsRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12@\n\nsubaccount\x18\x02 \x01(\x0b\x32&.injective.exchange.v1beta1.SubaccountB\x04\xc8\xde\x1f\x01\"\xd4\x01\n\x1fQuerySubaccountDepositsResponse\x12[\n\x08\x64\x65posits\x18\x01 \x03(\x0b\x32I.injective.exchange.v1beta1.QuerySubaccountDepositsResponse.DepositsEntry\x1aT\n\rDepositsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32#.injective.exchange.v1beta1.Deposit:\x02\x38\x01\"\x1e\n\x1cQueryExchangeBalancesRequest\"\\\n\x1dQueryExchangeBalancesResponse\x12;\n\x08\x62\x61lances\x18\x01 \x03(\x0b\x32#.injective.exchange.v1beta1.BalanceB\x04\xc8\xde\x1f\x00\".\n\x1bQueryAggregateVolumeRequest\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\t\"c\n\x1cQueryAggregateVolumeResponse\x12\x43\n\x11\x61ggregate_volumes\x18\x01 \x03(\x0b\x32(.injective.exchange.v1beta1.MarketVolume\"D\n\x1cQueryAggregateVolumesRequest\x12\x10\n\x08\x61\x63\x63ounts\x18\x01 \x03(\t\x12\x12\n\nmarket_ids\x18\x02 \x03(\t\"\xc8\x01\n\x1dQueryAggregateVolumesResponse\x12[\n\x19\x61ggregate_account_volumes\x18\x01 \x03(\x0b\x32\x38.injective.exchange.v1beta1.AggregateAccountVolumeRecord\x12J\n\x18\x61ggregate_market_volumes\x18\x02 \x03(\x0b\x32(.injective.exchange.v1beta1.MarketVolume\"6\n!QueryAggregateMarketVolumeRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\"d\n\"QueryAggregateMarketVolumeResponse\x12>\n\x06volume\x18\x01 \x01(\x0b\x32(.injective.exchange.v1beta1.VolumeRecordB\x04\xc8\xde\x1f\x00\")\n\x18QueryDenomDecimalRequest\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\",\n\x19QueryDenomDecimalResponse\x12\x0f\n\x07\x64\x65\x63imal\x18\x01 \x01(\x04\"+\n\x19QueryDenomDecimalsRequest\x12\x0e\n\x06\x64\x65noms\x18\x01 \x03(\t\"e\n\x1aQueryDenomDecimalsResponse\x12G\n\x0e\x64\x65nom_decimals\x18\x01 \x03(\x0b\x32).injective.exchange.v1beta1.DenomDecimalsB\x04\xc8\xde\x1f\x00\"8\n\"QueryAggregateMarketVolumesRequest\x12\x12\n\nmarket_ids\x18\x01 \x03(\t\"`\n#QueryAggregateMarketVolumesResponse\x12\x39\n\x07volumes\x18\x01 \x03(\x0b\x32(.injective.exchange.v1beta1.MarketVolume\"E\n\x1dQuerySubaccountDepositRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\t\"W\n\x1eQuerySubaccountDepositResponse\x12\x35\n\x08\x64\x65posits\x18\x01 \x01(\x0b\x32#.injective.exchange.v1beta1.Deposit\"=\n\x17QuerySpotMarketsRequest\x12\x0e\n\x06status\x18\x01 \x01(\t\x12\x12\n\nmarket_ids\x18\x02 \x03(\t\"S\n\x18QuerySpotMarketsResponse\x12\x37\n\x07markets\x18\x01 \x03(\x0b\x32&.injective.exchange.v1beta1.SpotMarket\"+\n\x16QuerySpotMarketRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\"Q\n\x17QuerySpotMarketResponse\x12\x36\n\x06market\x18\x01 \x01(\x0b\x32&.injective.exchange.v1beta1.SpotMarket\"\x9e\x02\n\x19QuerySpotOrderbookRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\x04\x12\x39\n\norder_side\x18\x03 \x01(\x0e\x32%.injective.exchange.v1beta1.OrderSide\x12Q\n\x19limit_cumulative_notional\x18\x04 \x01(\tB.\xc8\xde\x1f\x01\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12Q\n\x19limit_cumulative_quantity\x18\x05 \x01(\tB.\xc8\xde\x1f\x01\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\"\x97\x01\n\x1aQuerySpotOrderbookResponse\x12;\n\x10\x62uys_price_level\x18\x01 \x03(\x0b\x32!.injective.exchange.v1beta1.Level\x12<\n\x11sells_price_level\x18\x02 \x03(\x0b\x32!.injective.exchange.v1beta1.Level\"\x95\x01\n\x0e\x46ullSpotMarket\x12\x36\n\x06market\x18\x01 \x01(\x0b\x32&.injective.exchange.v1beta1.SpotMarket\x12K\n\x11mid_price_and_tob\x18\x02 \x01(\x0b\x32*.injective.exchange.v1beta1.MidPriceAndTOBB\x04\xc8\xde\x1f\x01\"a\n\x1bQueryFullSpotMarketsRequest\x12\x0e\n\x06status\x18\x01 \x01(\t\x12\x12\n\nmarket_ids\x18\x02 \x03(\t\x12\x1e\n\x16with_mid_price_and_tob\x18\x03 \x01(\x08\"[\n\x1cQueryFullSpotMarketsResponse\x12;\n\x07markets\x18\x01 \x03(\x0b\x32*.injective.exchange.v1beta1.FullSpotMarket\"O\n\x1aQueryFullSpotMarketRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x1e\n\x16with_mid_price_and_tob\x18\x02 \x01(\x08\"Y\n\x1bQueryFullSpotMarketResponse\x12:\n\x06market\x18\x01 \x01(\x0b\x32*.injective.exchange.v1beta1.FullSpotMarket\"`\n\x1eQuerySpotOrdersByHashesRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\t\x12\x14\n\x0corder_hashes\x18\x03 \x03(\t\"d\n\x1fQuerySpotOrdersByHashesResponse\x12\x41\n\x06orders\x18\x01 \x03(\x0b\x32\x31.injective.exchange.v1beta1.TrimmedSpotLimitOrder\"H\n\x1cQueryTraderSpotOrdersRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\t\"R\n$QueryAccountAddressSpotOrdersRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x17\n\x0f\x61\x63\x63ount_address\x18\x02 \x01(\t\"\xfd\x01\n\x15TrimmedSpotLimitOrder\x12=\n\x05price\x18\x01 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12@\n\x08quantity\x18\x02 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12@\n\x08\x66illable\x18\x03 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\r\n\x05isBuy\x18\x04 \x01(\x08\x12\x12\n\norder_hash\x18\x05 \x01(\t\"b\n\x1dQueryTraderSpotOrdersResponse\x12\x41\n\x06orders\x18\x01 \x03(\x0b\x32\x31.injective.exchange.v1beta1.TrimmedSpotLimitOrder\"j\n%QueryAccountAddressSpotOrdersResponse\x12\x41\n\x06orders\x18\x01 \x03(\x0b\x32\x31.injective.exchange.v1beta1.TrimmedSpotLimitOrder\"3\n\x1eQuerySpotMidPriceAndTOBRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\"\xf5\x01\n\x1fQuerySpotMidPriceAndTOBResponse\x12\x41\n\tmid_price\x18\x01 \x01(\tB.\xc8\xde\x1f\x01\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x46\n\x0e\x62\x65st_buy_price\x18\x02 \x01(\tB.\xc8\xde\x1f\x01\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12G\n\x0f\x62\x65st_sell_price\x18\x03 \x01(\tB.\xc8\xde\x1f\x01\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\"9\n$QueryDerivativeMidPriceAndTOBRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\"\xfb\x01\n%QueryDerivativeMidPriceAndTOBResponse\x12\x41\n\tmid_price\x18\x01 \x01(\tB.\xc8\xde\x1f\x01\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x46\n\x0e\x62\x65st_buy_price\x18\x02 \x01(\tB.\xc8\xde\x1f\x01\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12G\n\x0f\x62\x65st_sell_price\x18\x03 \x01(\tB.\xc8\xde\x1f\x01\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\"\x96\x01\n\x1fQueryDerivativeOrderbookRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\x04\x12Q\n\x19limit_cumulative_notional\x18\x03 \x01(\tB.\xc8\xde\x1f\x01\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\"\x9d\x01\n QueryDerivativeOrderbookResponse\x12;\n\x10\x62uys_price_level\x18\x01 \x03(\x0b\x32!.injective.exchange.v1beta1.Level\x12<\n\x11sells_price_level\x18\x02 \x03(\x0b\x32!.injective.exchange.v1beta1.Level\"\xf2\x02\n.QueryTraderSpotOrdersToCancelUpToAmountRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\t\x12\x43\n\x0b\x62\x61se_amount\x18\x03 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x44\n\x0cquote_amount\x18\x04 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x42\n\x08strategy\x18\x05 \x01(\x0e\x32\x30.injective.exchange.v1beta1.CancellationStrategy\x12G\n\x0freference_price\x18\x06 \x01(\tB.\xc8\xde\x1f\x01\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\"\xb3\x02\n4QueryTraderDerivativeOrdersToCancelUpToAmountRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\t\x12\x44\n\x0cquote_amount\x18\x03 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x42\n\x08strategy\x18\x04 \x01(\x0e\x32\x30.injective.exchange.v1beta1.CancellationStrategy\x12G\n\x0freference_price\x18\x05 \x01(\tB.\xc8\xde\x1f\x01\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\"N\n\"QueryTraderDerivativeOrdersRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\t\"X\n*QueryAccountAddressDerivativeOrdersRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x17\n\x0f\x61\x63\x63ount_address\x18\x02 \x01(\t\"\xce\x02\n\x1bTrimmedDerivativeLimitOrder\x12=\n\x05price\x18\x01 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12@\n\x08quantity\x18\x02 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12>\n\x06margin\x18\x03 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12@\n\x08\x66illable\x18\x04 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x18\n\x05isBuy\x18\x05 \x01(\x08\x42\t\xea\xde\x1f\x05isBuy\x12\x12\n\norder_hash\x18\x06 \x01(\t\"n\n#QueryTraderDerivativeOrdersResponse\x12G\n\x06orders\x18\x01 \x03(\x0b\x32\x37.injective.exchange.v1beta1.TrimmedDerivativeLimitOrder\"v\n+QueryAccountAddressDerivativeOrdersResponse\x12G\n\x06orders\x18\x01 \x03(\x0b\x32\x37.injective.exchange.v1beta1.TrimmedDerivativeLimitOrder\"f\n$QueryDerivativeOrdersByHashesRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\t\x12\x14\n\x0corder_hashes\x18\x03 \x03(\t\"p\n%QueryDerivativeOrdersByHashesResponse\x12G\n\x06orders\x18\x01 \x03(\x0b\x32\x37.injective.exchange.v1beta1.TrimmedDerivativeLimitOrder\"c\n\x1dQueryDerivativeMarketsRequest\x12\x0e\n\x06status\x18\x01 \x01(\t\x12\x12\n\nmarket_ids\x18\x02 \x03(\t\x12\x1e\n\x16with_mid_price_and_tob\x18\x03 \x01(\x08\"\x8d\x01\n\nPriceLevel\x12=\n\x05price\x18\x01 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12@\n\x08quantity\x18\x02 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\"\xa6\x01\n\x14PerpetualMarketState\x12\x44\n\x0bmarket_info\x18\x01 \x01(\x0b\x32/.injective.exchange.v1beta1.PerpetualMarketInfo\x12H\n\x0c\x66unding_info\x18\x02 \x01(\x0b\x32\x32.injective.exchange.v1beta1.PerpetualMarketFunding\"\x86\x03\n\x14\x46ullDerivativeMarket\x12<\n\x06market\x18\x01 \x01(\x0b\x32,.injective.exchange.v1beta1.DerivativeMarket\x12J\n\x0eperpetual_info\x18\x02 \x01(\x0b\x32\x30.injective.exchange.v1beta1.PerpetualMarketStateH\x00\x12K\n\x0c\x66utures_info\x18\x03 \x01(\x0b\x32\x33.injective.exchange.v1beta1.ExpiryFuturesMarketInfoH\x00\x12\x42\n\nmark_price\x18\x04 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12K\n\x11mid_price_and_tob\x18\x05 \x01(\x0b\x32*.injective.exchange.v1beta1.MidPriceAndTOBB\x04\xc8\xde\x1f\x01\x42\x06\n\x04info\"c\n\x1eQueryDerivativeMarketsResponse\x12\x41\n\x07markets\x18\x01 \x03(\x0b\x32\x30.injective.exchange.v1beta1.FullDerivativeMarket\"1\n\x1cQueryDerivativeMarketRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\"a\n\x1dQueryDerivativeMarketResponse\x12@\n\x06market\x18\x01 \x01(\x0b\x32\x30.injective.exchange.v1beta1.FullDerivativeMarket\"8\n#QueryDerivativeMarketAddressRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\"N\n$QueryDerivativeMarketAddressResponse\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\t\"9\n QuerySubaccountTradeNonceRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\"8\n\x1fQuerySubaccountPositionsRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\"R\n&QuerySubaccountPositionInMarketRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\"[\n/QuerySubaccountEffectivePositionInMarketRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\"<\n#QuerySubaccountOrderMetadataRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\"g\n QuerySubaccountPositionsResponse\x12\x43\n\x05state\x18\x01 \x03(\x0b\x32..injective.exchange.v1beta1.DerivativePositionB\x04\xc8\xde\x1f\x00\"d\n\'QuerySubaccountPositionInMarketResponse\x12\x39\n\x05state\x18\x01 \x01(\x0b\x32$.injective.exchange.v1beta1.PositionB\x04\xc8\xde\x1f\x01\"\xf5\x01\n\x11\x45\x66\x66\x65\x63tivePosition\x12\x0f\n\x07is_long\x18\x01 \x01(\x08\x12@\n\x08quantity\x18\x02 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x43\n\x0b\x65ntry_price\x18\x03 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12H\n\x10\x65\x66\x66\x65\x63tive_margin\x18\x04 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\"v\n0QuerySubaccountEffectivePositionInMarketResponse\x12\x42\n\x05state\x18\x01 \x01(\x0b\x32-.injective.exchange.v1beta1.EffectivePositionB\x04\xc8\xde\x1f\x01\"4\n\x1fQueryPerpetualMarketInfoRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\"g\n QueryPerpetualMarketInfoResponse\x12\x43\n\x04info\x18\x01 \x01(\x0b\x32/.injective.exchange.v1beta1.PerpetualMarketInfoB\x04\xc8\xde\x1f\x00\"8\n#QueryExpiryFuturesMarketInfoRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\"o\n$QueryExpiryFuturesMarketInfoResponse\x12G\n\x04info\x18\x01 \x01(\x0b\x32\x33.injective.exchange.v1beta1.ExpiryFuturesMarketInfoB\x04\xc8\xde\x1f\x00\"7\n\"QueryPerpetualMarketFundingRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\"n\n#QueryPerpetualMarketFundingResponse\x12G\n\x05state\x18\x01 \x01(\x0b\x32\x32.injective.exchange.v1beta1.PerpetualMarketFundingB\x04\xc8\xde\x1f\x00\"\x81\x01\n$QuerySubaccountOrderMetadataResponse\x12Y\n\x08metadata\x18\x01 \x03(\x0b\x32\x41.injective.exchange.v1beta1.SubaccountOrderbookMetadataWithMarketB\x04\xc8\xde\x1f\x00\"2\n!QuerySubaccountTradeNonceResponse\x12\r\n\x05nonce\x18\x01 \x01(\r\"\x19\n\x17QueryModuleStateRequest\"S\n\x18QueryModuleStateResponse\x12\x37\n\x05state\x18\x01 \x01(\x0b\x32(.injective.exchange.v1beta1.GenesisState\"\x17\n\x15QueryPositionsRequest\"]\n\x16QueryPositionsResponse\x12\x43\n\x05state\x18\x01 \x03(\x0b\x32..injective.exchange.v1beta1.DerivativePositionB\x04\xc8\xde\x1f\x00\"Q\n\x1dQueryTradeRewardPointsRequest\x12\x10\n\x08\x61\x63\x63ounts\x18\x01 \x03(\t\x12\x1e\n\x16pending_pool_timestamp\x18\x02 \x01(\x03\"u\n\x1eQueryTradeRewardPointsResponse\x12S\n\x1b\x61\x63\x63ount_trade_reward_points\x18\x01 \x03(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\"!\n\x1fQueryTradeRewardCampaignRequest\"\xf3\x03\n QueryTradeRewardCampaignResponse\x12[\n\x1ctrading_reward_campaign_info\x18\x01 \x01(\x0b\x32\x35.injective.exchange.v1beta1.TradingRewardCampaignInfo\x12]\n%trading_reward_pool_campaign_schedule\x18\x02 \x03(\x0b\x32..injective.exchange.v1beta1.CampaignRewardPool\x12Q\n\x19total_trade_reward_points\x18\x03 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x65\n-pending_trading_reward_pool_campaign_schedule\x18\x04 \x03(\x0b\x32..injective.exchange.v1beta1.CampaignRewardPool\x12Y\n!pending_total_trade_reward_points\x18\x05 \x03(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\"2\n\x1fQueryIsOptedOutOfRewardsRequest\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\t\"8\n QueryIsOptedOutOfRewardsResponse\x12\x14\n\x0cis_opted_out\x18\x01 \x01(\x08\"\'\n%QueryOptedOutOfRewardsAccountsRequest\":\n&QueryOptedOutOfRewardsAccountsResponse\x12\x10\n\x08\x61\x63\x63ounts\x18\x01 \x03(\t\"5\n\"QueryFeeDiscountAccountInfoRequest\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\t\"\xc5\x01\n#QueryFeeDiscountAccountInfoResponse\x12\x12\n\ntier_level\x18\x01 \x01(\x04\x12\x45\n\x0c\x61\x63\x63ount_info\x18\x02 \x01(\x0b\x32/.injective.exchange.v1beta1.FeeDiscountTierInfo\x12\x43\n\x0b\x61\x63\x63ount_ttl\x18\x03 \x01(\x0b\x32..injective.exchange.v1beta1.FeeDiscountTierTTL\"!\n\x1fQueryFeeDiscountScheduleRequest\"r\n QueryFeeDiscountScheduleResponse\x12N\n\x15\x66\x65\x65_discount_schedule\x18\x01 \x01(\x0b\x32/.injective.exchange.v1beta1.FeeDiscountSchedule\"4\n\x1dQueryBalanceMismatchesRequest\x12\x13\n\x0b\x64ust_factor\x18\x01 \x01(\x03\"\x8a\x03\n\x0f\x42\x61lanceMismatch\x12\x14\n\x0csubaccountId\x18\x01 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\t\x12\x41\n\tavailable\x18\x03 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12=\n\x05total\x18\x04 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x44\n\x0c\x62\x61lance_hold\x18\x05 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x46\n\x0e\x65xpected_total\x18\x06 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x42\n\ndifference\x18\x07 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\"i\n\x1eQueryBalanceMismatchesResponse\x12G\n\x12\x62\x61lance_mismatches\x18\x01 \x03(\x0b\x32+.injective.exchange.v1beta1.BalanceMismatch\"%\n#QueryBalanceWithBalanceHoldsRequest\"\x84\x02\n\x15\x42\x61lanceWithMarginHold\x12\x14\n\x0csubaccountId\x18\x01 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\t\x12\x41\n\tavailable\x18\x03 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12=\n\x05total\x18\x04 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x44\n\x0c\x62\x61lance_hold\x18\x05 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\"}\n$QueryBalanceWithBalanceHoldsResponse\x12U\n\x1a\x62\x61lance_with_balance_holds\x18\x01 \x03(\x0b\x32\x31.injective.exchange.v1beta1.BalanceWithMarginHold\"\'\n%QueryFeeDiscountTierStatisticsRequest\",\n\rTierStatistic\x12\x0c\n\x04tier\x18\x01 \x01(\x04\x12\r\n\x05\x63ount\x18\x02 \x01(\x04\"g\n&QueryFeeDiscountTierStatisticsResponse\x12=\n\nstatistics\x18\x01 \x03(\x0b\x32).injective.exchange.v1beta1.TierStatistic\"\x17\n\x15MitoVaultInfosRequest\"\x80\x01\n\x16MitoVaultInfosResponse\x12\x18\n\x10master_addresses\x18\x01 \x03(\t\x12\x1c\n\x14\x64\x65rivative_addresses\x18\x02 \x03(\t\x12\x16\n\x0espot_addresses\x18\x03 \x03(\t\x12\x16\n\x0e\x63w20_addresses\x18\x04 \x03(\t\"6\n\x1dQueryMarketIDFromVaultRequest\x12\x15\n\rvault_address\x18\x01 \x01(\t\"3\n\x1eQueryMarketIDFromVaultResponse\x12\x11\n\tmarket_id\x18\x01 \x01(\t\"7\n\"QueryHistoricalTradeRecordsRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\"f\n#QueryHistoricalTradeRecordsResponse\x12?\n\rtrade_records\x18\x01 \x03(\x0b\x32(.injective.exchange.v1beta1.TradeRecords\"y\n\x13TradeHistoryOptions\x12\x1a\n\x12trade_grouping_sec\x18\x01 \x01(\x04\x12\x0f\n\x07max_age\x18\x02 \x01(\x04\x12\x1b\n\x13include_raw_history\x18\x04 \x01(\x08\x12\x18\n\x10include_metadata\x18\x05 \x01(\x08\"\x81\x01\n\x1cQueryMarketVolatilityRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12N\n\x15trade_history_options\x18\x02 \x01(\x0b\x32/.injective.exchange.v1beta1.TradeHistoryOptions\"\xe5\x01\n\x1dQueryMarketVolatilityResponse\x12>\n\nvolatility\x18\x01 \x01(\tB*\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x46\n\x10history_metadata\x18\x02 \x01(\x0b\x32,.injective.oracle.v1beta1.MetadataStatistics\x12<\n\x0braw_history\x18\x03 \x03(\x0b\x32\'.injective.exchange.v1beta1.TradeRecord\"+\n\x19QueryBinaryMarketsRequest\x12\x0e\n\x06status\x18\x01 \x01(\t\"^\n\x1aQueryBinaryMarketsResponse\x12@\n\x07markets\x18\x01 \x03(\x0b\x32/.injective.exchange.v1beta1.BinaryOptionsMarket\"Y\n-QueryTraderDerivativeConditionalOrdersRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\"\xf6\x02\n!TrimmedDerivativeConditionalOrder\x12=\n\x05price\x18\x01 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12@\n\x08quantity\x18\x02 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12>\n\x06margin\x18\x03 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x44\n\x0ctriggerPrice\x18\x04 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x18\n\x05isBuy\x18\x05 \x01(\x08\x42\t\xea\xde\x1f\x05isBuy\x12\x1c\n\x07isLimit\x18\x06 \x01(\x08\x42\x0b\xea\xde\x1f\x07isLimit\x12\x12\n\norder_hash\x18\x07 \x01(\t\"\x7f\n.QueryTraderDerivativeConditionalOrdersResponse\x12M\n\x06orders\x18\x01 \x03(\x0b\x32=.injective.exchange.v1beta1.TrimmedDerivativeConditionalOrder\"C\n.QueryMarketAtomicExecutionFeeMultiplierRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\"u\n/QueryMarketAtomicExecutionFeeMultiplierResponse\x12\x42\n\nmultiplier\x18\x01 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec*4\n\tOrderSide\x12\x14\n\x10Side_Unspecified\x10\x00\x12\x07\n\x03\x42uy\x10\x01\x12\x08\n\x04Sell\x10\x02*V\n\x14\x43\x61ncellationStrategy\x12\x14\n\x10UnspecifiedOrder\x10\x00\x12\x13\n\x0f\x46romWorstToBest\x10\x01\x12\x13\n\x0f\x46romBestToWorst\x10\x02\x32\xcd`\n\x05Query\x12\xba\x01\n\x13QueryExchangeParams\x12\x36.injective.exchange.v1beta1.QueryExchangeParamsRequest\x1a\x37.injective.exchange.v1beta1.QueryExchangeParamsResponse\"2\x82\xd3\xe4\x93\x02,\x12*/injective/exchange/v1beta1/exchangeParams\x12\xce\x01\n\x12SubaccountDeposits\x12:.injective.exchange.v1beta1.QuerySubaccountDepositsRequest\x1a;.injective.exchange.v1beta1.QuerySubaccountDepositsResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/injective/exchange/v1beta1/exchange/subaccountDeposits\x12\xca\x01\n\x11SubaccountDeposit\x12\x39.injective.exchange.v1beta1.QuerySubaccountDepositRequest\x1a:.injective.exchange.v1beta1.QuerySubaccountDepositResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/injective/exchange/v1beta1/exchange/subaccountDeposit\x12\xc6\x01\n\x10\x45xchangeBalances\x12\x38.injective.exchange.v1beta1.QueryExchangeBalancesRequest\x1a\x39.injective.exchange.v1beta1.QueryExchangeBalancesResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/injective/exchange/v1beta1/exchange/exchangeBalances\x12\xcc\x01\n\x0f\x41ggregateVolume\x12\x37.injective.exchange.v1beta1.QueryAggregateVolumeRequest\x1a\x38.injective.exchange.v1beta1.QueryAggregateVolumeResponse\"F\x82\xd3\xe4\x93\x02@\x12>/injective/exchange/v1beta1/exchange/aggregateVolume/{account}\x12\xc6\x01\n\x10\x41ggregateVolumes\x12\x38.injective.exchange.v1beta1.QueryAggregateVolumesRequest\x1a\x39.injective.exchange.v1beta1.QueryAggregateVolumesResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/injective/exchange/v1beta1/exchange/aggregateVolumes\x12\xe6\x01\n\x15\x41ggregateMarketVolume\x12=.injective.exchange.v1beta1.QueryAggregateMarketVolumeRequest\x1a>.injective.exchange.v1beta1.QueryAggregateMarketVolumeResponse\"N\x82\xd3\xe4\x93\x02H\x12\x46/injective/exchange/v1beta1/exchange/aggregateMarketVolume/{market_id}\x12\xde\x01\n\x16\x41ggregateMarketVolumes\x12>.injective.exchange.v1beta1.QueryAggregateMarketVolumesRequest\x1a?.injective.exchange.v1beta1.QueryAggregateMarketVolumesResponse\"C\x82\xd3\xe4\x93\x02=\x12;/injective/exchange/v1beta1/exchange/aggregateMarketVolumes\x12\xbf\x01\n\x0c\x44\x65nomDecimal\x12\x34.injective.exchange.v1beta1.QueryDenomDecimalRequest\x1a\x35.injective.exchange.v1beta1.QueryDenomDecimalResponse\"B\x82\xd3\xe4\x93\x02<\x12:/injective/exchange/v1beta1/exchange/denom_decimal/{denom}\x12\xbb\x01\n\rDenomDecimals\x12\x35.injective.exchange.v1beta1.QueryDenomDecimalsRequest\x1a\x36.injective.exchange.v1beta1.QueryDenomDecimalsResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/injective/exchange/v1beta1/exchange/denom_decimals\x12\xaa\x01\n\x0bSpotMarkets\x12\x33.injective.exchange.v1beta1.QuerySpotMarketsRequest\x1a\x34.injective.exchange.v1beta1.QuerySpotMarketsResponse\"0\x82\xd3\xe4\x93\x02*\x12(/injective/exchange/v1beta1/spot/markets\x12\xb3\x01\n\nSpotMarket\x12\x32.injective.exchange.v1beta1.QuerySpotMarketRequest\x1a\x33.injective.exchange.v1beta1.QuerySpotMarketResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/injective/exchange/v1beta1/spot/markets/{market_id}\x12\xbb\x01\n\x0f\x46ullSpotMarkets\x12\x37.injective.exchange.v1beta1.QueryFullSpotMarketsRequest\x1a\x38.injective.exchange.v1beta1.QueryFullSpotMarketsResponse\"5\x82\xd3\xe4\x93\x02/\x12-/injective/exchange/v1beta1/spot/full_markets\x12\xc3\x01\n\x0e\x46ullSpotMarket\x12\x36.injective.exchange.v1beta1.QueryFullSpotMarketRequest\x1a\x37.injective.exchange.v1beta1.QueryFullSpotMarketResponse\"@\x82\xd3\xe4\x93\x02:\x12\x38/injective/exchange/v1beta1/spot/full_market/{market_id}\x12\xbe\x01\n\rSpotOrderbook\x12\x35.injective.exchange.v1beta1.QuerySpotOrderbookRequest\x1a\x36.injective.exchange.v1beta1.QuerySpotOrderbookResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/injective/exchange/v1beta1/spot/orderbook/{market_id}\x12\xd4\x01\n\x10TraderSpotOrders\x12\x38.injective.exchange.v1beta1.QueryTraderSpotOrdersRequest\x1a\x39.injective.exchange.v1beta1.QueryTraderSpotOrdersResponse\"K\x82\xd3\xe4\x93\x02\x45\x12\x43/injective/exchange/v1beta1/spot/orders/{market_id}/{subaccount_id}\x12\xf6\x01\n\x18\x41\x63\x63ountAddressSpotOrders\x12@.injective.exchange.v1beta1.QueryAccountAddressSpotOrdersRequest\x1a\x41.injective.exchange.v1beta1.QueryAccountAddressSpotOrdersResponse\"U\x82\xd3\xe4\x93\x02O\x12M/injective/exchange/v1beta1/spot/orders/{market_id}/account/{account_address}\x12\xe4\x01\n\x12SpotOrdersByHashes\x12:.injective.exchange.v1beta1.QuerySpotOrdersByHashesRequest\x1a;.injective.exchange.v1beta1.QuerySpotOrdersByHashesResponse\"U\x82\xd3\xe4\x93\x02O\x12M/injective/exchange/v1beta1/spot/orders_by_hashes/{market_id}/{subaccount_id}\x12\xc3\x01\n\x10SubaccountOrders\x12\x38.injective.exchange.v1beta1.QuerySubaccountOrdersRequest\x1a\x39.injective.exchange.v1beta1.QuerySubaccountOrdersResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/injective/exchange/v1beta1/orders/{subaccount_id}\x12\xe7\x01\n\x19TraderSpotTransientOrders\x12\x38.injective.exchange.v1beta1.QueryTraderSpotOrdersRequest\x1a\x39.injective.exchange.v1beta1.QueryTraderSpotOrdersResponse\"U\x82\xd3\xe4\x93\x02O\x12M/injective/exchange/v1beta1/spot/transient_orders/{market_id}/{subaccount_id}\x12\xd5\x01\n\x12SpotMidPriceAndTOB\x12:.injective.exchange.v1beta1.QuerySpotMidPriceAndTOBRequest\x1a;.injective.exchange.v1beta1.QuerySpotMidPriceAndTOBResponse\"F\x82\xd3\xe4\x93\x02@\x12>/injective/exchange/v1beta1/spot/mid_price_and_tob/{market_id}\x12\xed\x01\n\x18\x44\x65rivativeMidPriceAndTOB\x12@.injective.exchange.v1beta1.QueryDerivativeMidPriceAndTOBRequest\x1a\x41.injective.exchange.v1beta1.QueryDerivativeMidPriceAndTOBResponse\"L\x82\xd3\xe4\x93\x02\x46\x12\x44/injective/exchange/v1beta1/derivative/mid_price_and_tob/{market_id}\x12\xd6\x01\n\x13\x44\x65rivativeOrderbook\x12;.injective.exchange.v1beta1.QueryDerivativeOrderbookRequest\x1a<.injective.exchange.v1beta1.QueryDerivativeOrderbookResponse\"D\x82\xd3\xe4\x93\x02>\x12</injective/exchange/v1beta1/derivative/orderbook/{market_id}\x12\xec\x01\n\x16TraderDerivativeOrders\x12>.injective.exchange.v1beta1.QueryTraderDerivativeOrdersRequest\x1a?.injective.exchange.v1beta1.QueryTraderDerivativeOrdersResponse\"Q\x82\xd3\xe4\x93\x02K\x12I/injective/exchange/v1beta1/derivative/orders/{market_id}/{subaccount_id}\x12\x8e\x02\n\x1e\x41\x63\x63ountAddressDerivativeOrders\x12\x46.injective.exchange.v1beta1.QueryAccountAddressDerivativeOrdersRequest\x1aG.injective.exchange.v1beta1.QueryAccountAddressDerivativeOrdersResponse\"[\x82\xd3\xe4\x93\x02U\x12S/injective/exchange/v1beta1/derivative/orders/{market_id}/account/{account_address}\x12\xfc\x01\n\x18\x44\x65rivativeOrdersByHashes\x12@.injective.exchange.v1beta1.QueryDerivativeOrdersByHashesRequest\x1a\x41.injective.exchange.v1beta1.QueryDerivativeOrdersByHashesResponse\"[\x82\xd3\xe4\x93\x02U\x12S/injective/exchange/v1beta1/derivative/orders_by_hashes/{market_id}/{subaccount_id}\x12\xff\x01\n\x1fTraderDerivativeTransientOrders\x12>.injective.exchange.v1beta1.QueryTraderDerivativeOrdersRequest\x1a?.injective.exchange.v1beta1.QueryTraderDerivativeOrdersResponse\"[\x82\xd3\xe4\x93\x02U\x12S/injective/exchange/v1beta1/derivative/transient_orders/{market_id}/{subaccount_id}\x12\xc2\x01\n\x11\x44\x65rivativeMarkets\x12\x39.injective.exchange.v1beta1.QueryDerivativeMarketsRequest\x1a:.injective.exchange.v1beta1.QueryDerivativeMarketsResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./injective/exchange/v1beta1/derivative/markets\x12\xcb\x01\n\x10\x44\x65rivativeMarket\x12\x38.injective.exchange.v1beta1.QueryDerivativeMarketRequest\x1a\x39.injective.exchange.v1beta1.QueryDerivativeMarketResponse\"B\x82\xd3\xe4\x93\x02<\x12:/injective/exchange/v1beta1/derivative/markets/{market_id}\x12\xe7\x01\n\x17\x44\x65rivativeMarketAddress\x12?.injective.exchange.v1beta1.QueryDerivativeMarketAddressRequest\x1a@.injective.exchange.v1beta1.QueryDerivativeMarketAddressResponse\"I\x82\xd3\xe4\x93\x02\x43\x12\x41/injective/exchange/v1beta1/derivative/market_address/{market_id}\x12\xd1\x01\n\x14SubaccountTradeNonce\x12<.injective.exchange.v1beta1.QuerySubaccountTradeNonceRequest\x1a=.injective.exchange.v1beta1.QuerySubaccountTradeNonceResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/injective/exchange/v1beta1/exchange/{subaccount_id}\x12\xb2\x01\n\x13\x45xchangeModuleState\x12\x33.injective.exchange.v1beta1.QueryModuleStateRequest\x1a\x34.injective.exchange.v1beta1.QueryModuleStateResponse\"0\x82\xd3\xe4\x93\x02*\x12(/injective/exchange/v1beta1/module_state\x12\xa1\x01\n\tPositions\x12\x31.injective.exchange.v1beta1.QueryPositionsRequest\x1a\x32.injective.exchange.v1beta1.QueryPositionsResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/injective/exchange/v1beta1/positions\x12\xcf\x01\n\x13SubaccountPositions\x12;.injective.exchange.v1beta1.QuerySubaccountPositionsRequest\x1a<.injective.exchange.v1beta1.QuerySubaccountPositionsResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/injective/exchange/v1beta1/positions/{subaccount_id}\x12\xf0\x01\n\x1aSubaccountPositionInMarket\x12\x42.injective.exchange.v1beta1.QuerySubaccountPositionInMarketRequest\x1a\x43.injective.exchange.v1beta1.QuerySubaccountPositionInMarketResponse\"I\x82\xd3\xe4\x93\x02\x43\x12\x41/injective/exchange/v1beta1/positions/{subaccount_id}/{market_id}\x12\x95\x02\n#SubaccountEffectivePositionInMarket\x12K.injective.exchange.v1beta1.QuerySubaccountEffectivePositionInMarketRequest\x1aL.injective.exchange.v1beta1.QuerySubaccountEffectivePositionInMarketResponse\"S\x82\xd3\xe4\x93\x02M\x12K/injective/exchange/v1beta1/effective_positions/{subaccount_id}/{market_id}\x12\xd7\x01\n\x13PerpetualMarketInfo\x12;.injective.exchange.v1beta1.QueryPerpetualMarketInfoRequest\x1a<.injective.exchange.v1beta1.QueryPerpetualMarketInfoResponse\"E\x82\xd3\xe4\x93\x02?\x12=/injective/exchange/v1beta1/perpetual_market_info/{market_id}\x12\xe0\x01\n\x17\x45xpiryFuturesMarketInfo\x12?.injective.exchange.v1beta1.QueryExpiryFuturesMarketInfoRequest\x1a@.injective.exchange.v1beta1.QueryExpiryFuturesMarketInfoResponse\"B\x82\xd3\xe4\x93\x02<\x12:/injective/exchange/v1beta1/expiry_market_info/{market_id}\x12\xe3\x01\n\x16PerpetualMarketFunding\x12>.injective.exchange.v1beta1.QueryPerpetualMarketFundingRequest\x1a?.injective.exchange.v1beta1.QueryPerpetualMarketFundingResponse\"H\x82\xd3\xe4\x93\x02\x42\x12@/injective/exchange/v1beta1/perpetual_market_funding/{market_id}\x12\xe0\x01\n\x17SubaccountOrderMetadata\x12?.injective.exchange.v1beta1.QuerySubaccountOrderMetadataRequest\x1a@.injective.exchange.v1beta1.QuerySubaccountOrderMetadataResponse\"B\x82\xd3\xe4\x93\x02<\x12:/injective/exchange/v1beta1/order_metadata/{subaccount_id}\x12\xc3\x01\n\x11TradeRewardPoints\x12\x39.injective.exchange.v1beta1.QueryTradeRewardPointsRequest\x1a:.injective.exchange.v1beta1.QueryTradeRewardPointsResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//injective/exchange/v1beta1/trade_reward_points\x12\xd2\x01\n\x18PendingTradeRewardPoints\x12\x39.injective.exchange.v1beta1.QueryTradeRewardPointsRequest\x1a:.injective.exchange.v1beta1.QueryTradeRewardPointsResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/injective/exchange/v1beta1/pending_trade_reward_points\x12\xcb\x01\n\x13TradeRewardCampaign\x12;.injective.exchange.v1beta1.QueryTradeRewardCampaignRequest\x1a<.injective.exchange.v1beta1.QueryTradeRewardCampaignResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/injective/exchange/v1beta1/trade_reward_campaign\x12\xe2\x01\n\x16\x46\x65\x65\x44iscountAccountInfo\x12>.injective.exchange.v1beta1.QueryFeeDiscountAccountInfoRequest\x1a?.injective.exchange.v1beta1.QueryFeeDiscountAccountInfoResponse\"G\x82\xd3\xe4\x93\x02\x41\x12?/injective/exchange/v1beta1/fee_discount_account_info/{account}\x12\xcb\x01\n\x13\x46\x65\x65\x44iscountSchedule\x12;.injective.exchange.v1beta1.QueryFeeDiscountScheduleRequest\x1a<.injective.exchange.v1beta1.QueryFeeDiscountScheduleResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/injective/exchange/v1beta1/fee_discount_schedule\x12\xd0\x01\n\x11\x42\x61lanceMismatches\x12\x39.injective.exchange.v1beta1.QueryBalanceMismatchesRequest\x1a:.injective.exchange.v1beta1.QueryBalanceMismatchesResponse\"D\x82\xd3\xe4\x93\x02>\x12</injective/exchange/v1beta1/balance_mismatches/{dust_factor}\x12\xdd\x01\n\x17\x42\x61lanceWithBalanceHolds\x12?.injective.exchange.v1beta1.QueryBalanceWithBalanceHoldsRequest\x1a@.injective.exchange.v1beta1.QueryBalanceWithBalanceHoldsResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/injective/exchange/v1beta1/balances_with_balance_holds\x12\xdf\x01\n\x19\x46\x65\x65\x44iscountTierStatistics\x12\x41.injective.exchange.v1beta1.QueryFeeDiscountTierStatisticsRequest\x1a\x42.injective.exchange.v1beta1.QueryFeeDiscountTierStatisticsResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/injective/exchange/v1beta1/fee_discount_tier_stats\x12\xad\x01\n\x0eMitoVaultInfos\x12\x31.injective.exchange.v1beta1.MitoVaultInfosRequest\x1a\x32.injective.exchange.v1beta1.MitoVaultInfosResponse\"4\x82\xd3\xe4\x93\x02.\x12,/injective/exchange/v1beta1/mito_vault_infos\x12\xd4\x01\n\x16QueryMarketIDFromVault\x12\x39.injective.exchange.v1beta1.QueryMarketIDFromVaultRequest\x1a:.injective.exchange.v1beta1.QueryMarketIDFromVaultResponse\"C\x82\xd3\xe4\x93\x02=\x12;/injective/exchange/v1beta1/vault_market_id/{vault_address}\x12\xd7\x01\n\x16HistoricalTradeRecords\x12>.injective.exchange.v1beta1.QueryHistoricalTradeRecordsRequest\x1a?.injective.exchange.v1beta1.QueryHistoricalTradeRecordsResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/injective/exchange/v1beta1/historical_trade_records\x12\xd7\x01\n\x13IsOptedOutOfRewards\x12;.injective.exchange.v1beta1.QueryIsOptedOutOfRewardsRequest\x1a<.injective.exchange.v1beta1.QueryIsOptedOutOfRewardsResponse\"E\x82\xd3\xe4\x93\x02?\x12=/injective/exchange/v1beta1/is_opted_out_of_rewards/{account}\x12\xe5\x01\n\x19OptedOutOfRewardsAccounts\x12\x41.injective.exchange.v1beta1.QueryOptedOutOfRewardsAccountsRequest\x1a\x42.injective.exchange.v1beta1.QueryOptedOutOfRewardsAccountsResponse\"A\x82\xd3\xe4\x93\x02;\x12\x39/injective/exchange/v1beta1/opted_out_of_rewards_accounts\x12\xca\x01\n\x10MarketVolatility\x12\x38.injective.exchange.v1beta1.QueryMarketVolatilityRequest\x1a\x39.injective.exchange.v1beta1.QueryMarketVolatilityResponse\"A\x82\xd3\xe4\x93\x02;\x12\x39/injective/exchange/v1beta1/market_volatility/{market_id}\x12\xc1\x01\n\x14\x42inaryOptionsMarkets\x12\x35.injective.exchange.v1beta1.QueryBinaryMarketsRequest\x1a\x36.injective.exchange.v1beta1.QueryBinaryMarketsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/injective/exchange/v1beta1/binary_options/markets\x12\x99\x02\n!TraderDerivativeConditionalOrders\x12I.injective.exchange.v1beta1.QueryTraderDerivativeConditionalOrdersRequest\x1aJ.injective.exchange.v1beta1.QueryTraderDerivativeConditionalOrdersResponse\"]\x82\xd3\xe4\x93\x02W\x12U/injective/exchange/v1beta1/derivative/orders/conditional/{market_id}/{subaccount_id}\x12\xfe\x01\n\"MarketAtomicExecutionFeeMultiplier\x12J.injective.exchange.v1beta1.QueryMarketAtomicExecutionFeeMultiplierRequest\x1aK.injective.exchange.v1beta1.QueryMarketAtomicExecutionFeeMultiplierResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/injective/exchange/v1beta1/atomic_order_fee_multiplierBPZNgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.exchange.v1beta1.query_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZNgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/types'
  _QUERYEXCHANGEPARAMSRESPONSE.fields_by_name['params']._options = None
  _QUERYEXCHANGEPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _QUERYSUBACCOUNTDEPOSITSREQUEST.fields_by_name['subaccount']._options = None
  _QUERYSUBACCOUNTDEPOSITSREQUEST.fields_by_name['subaccount']._serialized_options = b'\310\336\037\001'
  _QUERYSUBACCOUNTDEPOSITSRESPONSE_DEPOSITSENTRY._options = None
  _QUERYSUBACCOUNTDEPOSITSRESPONSE_DEPOSITSENTRY._serialized_options = b'8\001'
  _QUERYEXCHANGEBALANCESRESPONSE.fields_by_name['balances']._options = None
  _QUERYEXCHANGEBALANCESRESPONSE.fields_by_name['balances']._serialized_options = b'\310\336\037\000'
  _QUERYAGGREGATEMARKETVOLUMERESPONSE.fields_by_name['volume']._options = None
  _QUERYAGGREGATEMARKETVOLUMERESPONSE.fields_by_name['volume']._serialized_options = b'\310\336\037\000'
  _QUERYDENOMDECIMALSRESPONSE.fields_by_name['denom_decimals']._options = None
  _QUERYDENOMDECIMALSRESPONSE.fields_by_name['denom_decimals']._serialized_options = b'\310\336\037\000'
  _QUERYSPOTORDERBOOKREQUEST.fields_by_name['limit_cumulative_notional']._options = None
  _QUERYSPOTORDERBOOKREQUEST.fields_by_name['limit_cumulative_notional']._serialized_options = b'\310\336\037\001\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _QUERYSPOTORDERBOOKREQUEST.fields_by_name['limit_cumulative_quantity']._options = None
  _QUERYSPOTORDERBOOKREQUEST.fields_by_name['limit_cumulative_quantity']._serialized_options = b'\310\336\037\001\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _FULLSPOTMARKET.fields_by_name['mid_price_and_tob']._options = None
  _FULLSPOTMARKET.fields_by_name['mid_price_and_tob']._serialized_options = b'\310\336\037\001'
  _TRIMMEDSPOTLIMITORDER.fields_by_name['price']._options = None
  _TRIMMEDSPOTLIMITORDER.fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _TRIMMEDSPOTLIMITORDER.fields_by_name['quantity']._options = None
  _TRIMMEDSPOTLIMITORDER.fields_by_name['quantity']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _TRIMMEDSPOTLIMITORDER.fields_by_name['fillable']._options = None
  _TRIMMEDSPOTLIMITORDER.fields_by_name['fillable']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _QUERYSPOTMIDPRICEANDTOBRESPONSE.fields_by_name['mid_price']._options = None
  _QUERYSPOTMIDPRICEANDTOBRESPONSE.fields_by_name['mid_price']._serialized_options = b'\310\336\037\001\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _QUERYSPOTMIDPRICEANDTOBRESPONSE.fields_by_name['best_buy_price']._options = None
  _QUERYSPOTMIDPRICEANDTOBRESPONSE.fields_by_name['best_buy_price']._serialized_options = b'\310\336\037\001\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _QUERYSPOTMIDPRICEANDTOBRESPONSE.fields_by_name['best_sell_price']._options = None
  _QUERYSPOTMIDPRICEANDTOBRESPONSE.fields_by_name['best_sell_price']._serialized_options = b'\310\336\037\001\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _QUERYDERIVATIVEMIDPRICEANDTOBRESPONSE.fields_by_name['mid_price']._options = None
  _QUERYDERIVATIVEMIDPRICEANDTOBRESPONSE.fields_by_name['mid_price']._serialized_options = b'\310\336\037\001\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _QUERYDERIVATIVEMIDPRICEANDTOBRESPONSE.fields_by_name['best_buy_price']._options = None
  _QUERYDERIVATIVEMIDPRICEANDTOBRESPONSE.fields_by_name['best_buy_price']._serialized_options = b'\310\336\037\001\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _QUERYDERIVATIVEMIDPRICEANDTOBRESPONSE.fields_by_name['best_sell_price']._options = None
  _QUERYDERIVATIVEMIDPRICEANDTOBRESPONSE.fields_by_name['best_sell_price']._serialized_options = b'\310\336\037\001\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _QUERYDERIVATIVEORDERBOOKREQUEST.fields_by_name['limit_cumulative_notional']._options = None
  _QUERYDERIVATIVEORDERBOOKREQUEST.fields_by_name['limit_cumulative_notional']._serialized_options = b'\310\336\037\001\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _QUERYTRADERSPOTORDERSTOCANCELUPTOAMOUNTREQUEST.fields_by_name['base_amount']._options = None
  _QUERYTRADERSPOTORDERSTOCANCELUPTOAMOUNTREQUEST.fields_by_name['base_amount']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _QUERYTRADERSPOTORDERSTOCANCELUPTOAMOUNTREQUEST.fields_by_name['quote_amount']._options = None
  _QUERYTRADERSPOTORDERSTOCANCELUPTOAMOUNTREQUEST.fields_by_name['quote_amount']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _QUERYTRADERSPOTORDERSTOCANCELUPTOAMOUNTREQUEST.fields_by_name['reference_price']._options = None
  _QUERYTRADERSPOTORDERSTOCANCELUPTOAMOUNTREQUEST.fields_by_name['reference_price']._serialized_options = b'\310\336\037\001\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _QUERYTRADERDERIVATIVEORDERSTOCANCELUPTOAMOUNTREQUEST.fields_by_name['quote_amount']._options = None
  _QUERYTRADERDERIVATIVEORDERSTOCANCELUPTOAMOUNTREQUEST.fields_by_name['quote_amount']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _QUERYTRADERDERIVATIVEORDERSTOCANCELUPTOAMOUNTREQUEST.fields_by_name['reference_price']._options = None
  _QUERYTRADERDERIVATIVEORDERSTOCANCELUPTOAMOUNTREQUEST.fields_by_name['reference_price']._serialized_options = b'\310\336\037\001\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _TRIMMEDDERIVATIVELIMITORDER.fields_by_name['price']._options = None
  _TRIMMEDDERIVATIVELIMITORDER.fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _TRIMMEDDERIVATIVELIMITORDER.fields_by_name['quantity']._options = None
  _TRIMMEDDERIVATIVELIMITORDER.fields_by_name['quantity']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _TRIMMEDDERIVATIVELIMITORDER.fields_by_name['margin']._options = None
  _TRIMMEDDERIVATIVELIMITORDER.fields_by_name['margin']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _TRIMMEDDERIVATIVELIMITORDER.fields_by_name['fillable']._options = None
  _TRIMMEDDERIVATIVELIMITORDER.fields_by_name['fillable']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _TRIMMEDDERIVATIVELIMITORDER.fields_by_name['isBuy']._options = None
  _TRIMMEDDERIVATIVELIMITORDER.fields_by_name['isBuy']._serialized_options = b'\352\336\037\005isBuy'
  _PRICELEVEL.fields_by_name['price']._options = None
  _PRICELEVEL.fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _PRICELEVEL.fields_by_name['quantity']._options = None
  _PRICELEVEL.fields_by_name['quantity']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _FULLDERIVATIVEMARKET.fields_by_name['mark_price']._options = None
  _FULLDERIVATIVEMARKET.fields_by_name['mark_price']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _FULLDERIVATIVEMARKET.fields_by_name['mid_price_and_tob']._options = None
  _FULLDERIVATIVEMARKET.fields_by_name['mid_price_and_tob']._serialized_options = b'\310\336\037\001'
  _QUERYSUBACCOUNTPOSITIONSRESPONSE.fields_by_name['state']._options = None
  _QUERYSUBACCOUNTPOSITIONSRESPONSE.fields_by_name['state']._serialized_options = b'\310\336\037\000'
  _QUERYSUBACCOUNTPOSITIONINMARKETRESPONSE.fields_by_name['state']._options = None
  _QUERYSUBACCOUNTPOSITIONINMARKETRESPONSE.fields_by_name['state']._serialized_options = b'\310\336\037\001'
  _EFFECTIVEPOSITION.fields_by_name['quantity']._options = None
  _EFFECTIVEPOSITION.fields_by_name['quantity']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _EFFECTIVEPOSITION.fields_by_name['entry_price']._options = None
  _EFFECTIVEPOSITION.fields_by_name['entry_price']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _EFFECTIVEPOSITION.fields_by_name['effective_margin']._options = None
  _EFFECTIVEPOSITION.fields_by_name['effective_margin']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _QUERYSUBACCOUNTEFFECTIVEPOSITIONINMARKETRESPONSE.fields_by_name['state']._options = None
  _QUERYSUBACCOUNTEFFECTIVEPOSITIONINMARKETRESPONSE.fields_by_name['state']._serialized_options = b'\310\336\037\001'
  _QUERYPERPETUALMARKETINFORESPONSE.fields_by_name['info']._options = None
  _QUERYPERPETUALMARKETINFORESPONSE.fields_by_name['info']._serialized_options = b'\310\336\037\000'
  _QUERYEXPIRYFUTURESMARKETINFORESPONSE.fields_by_name['info']._options = None
  _QUERYEXPIRYFUTURESMARKETINFORESPONSE.fields_by_name['info']._serialized_options = b'\310\336\037\000'
  _QUERYPERPETUALMARKETFUNDINGRESPONSE.fields_by_name['state']._options = None
  _QUERYPERPETUALMARKETFUNDINGRESPONSE.fields_by_name['state']._serialized_options = b'\310\336\037\000'
  _QUERYSUBACCOUNTORDERMETADATARESPONSE.fields_by_name['metadata']._options = None
  _QUERYSUBACCOUNTORDERMETADATARESPONSE.fields_by_name['metadata']._serialized_options = b'\310\336\037\000'
  _QUERYPOSITIONSRESPONSE.fields_by_name['state']._options = None
  _QUERYPOSITIONSRESPONSE.fields_by_name['state']._serialized_options = b'\310\336\037\000'
  _QUERYTRADEREWARDPOINTSRESPONSE.fields_by_name['account_trade_reward_points']._options = None
  _QUERYTRADEREWARDPOINTSRESPONSE.fields_by_name['account_trade_reward_points']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _QUERYTRADEREWARDCAMPAIGNRESPONSE.fields_by_name['total_trade_reward_points']._options = None
  _QUERYTRADEREWARDCAMPAIGNRESPONSE.fields_by_name['total_trade_reward_points']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _QUERYTRADEREWARDCAMPAIGNRESPONSE.fields_by_name['pending_total_trade_reward_points']._options = None
  _QUERYTRADEREWARDCAMPAIGNRESPONSE.fields_by_name['pending_total_trade_reward_points']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _BALANCEMISMATCH.fields_by_name['available']._options = None
  _BALANCEMISMATCH.fields_by_name['available']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _BALANCEMISMATCH.fields_by_name['total']._options = None
  _BALANCEMISMATCH.fields_by_name['total']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _BALANCEMISMATCH.fields_by_name['balance_hold']._options = None
  _BALANCEMISMATCH.fields_by_name['balance_hold']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _BALANCEMISMATCH.fields_by_name['expected_total']._options = None
  _BALANCEMISMATCH.fields_by_name['expected_total']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _BALANCEMISMATCH.fields_by_name['difference']._options = None
  _BALANCEMISMATCH.fields_by_name['difference']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _BALANCEWITHMARGINHOLD.fields_by_name['available']._options = None
  _BALANCEWITHMARGINHOLD.fields_by_name['available']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _BALANCEWITHMARGINHOLD.fields_by_name['total']._options = None
  _BALANCEWITHMARGINHOLD.fields_by_name['total']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _BALANCEWITHMARGINHOLD.fields_by_name['balance_hold']._options = None
  _BALANCEWITHMARGINHOLD.fields_by_name['balance_hold']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _QUERYMARKETVOLATILITYRESPONSE.fields_by_name['volatility']._options = None
  _QUERYMARKETVOLATILITYRESPONSE.fields_by_name['volatility']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _TRIMMEDDERIVATIVECONDITIONALORDER.fields_by_name['price']._options = None
  _TRIMMEDDERIVATIVECONDITIONALORDER.fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _TRIMMEDDERIVATIVECONDITIONALORDER.fields_by_name['quantity']._options = None
  _TRIMMEDDERIVATIVECONDITIONALORDER.fields_by_name['quantity']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _TRIMMEDDERIVATIVECONDITIONALORDER.fields_by_name['margin']._options = None
  _TRIMMEDDERIVATIVECONDITIONALORDER.fields_by_name['margin']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _TRIMMEDDERIVATIVECONDITIONALORDER.fields_by_name['triggerPrice']._options = None
  _TRIMMEDDERIVATIVECONDITIONALORDER.fields_by_name['triggerPrice']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _TRIMMEDDERIVATIVECONDITIONALORDER.fields_by_name['isBuy']._options = None
  _TRIMMEDDERIVATIVECONDITIONALORDER.fields_by_name['isBuy']._serialized_options = b'\352\336\037\005isBuy'
  _TRIMMEDDERIVATIVECONDITIONALORDER.fields_by_name['isLimit']._options = None
  _TRIMMEDDERIVATIVECONDITIONALORDER.fields_by_name['isLimit']._serialized_options = b'\352\336\037\007isLimit'
  _QUERYMARKETATOMICEXECUTIONFEEMULTIPLIERRESPONSE.fields_by_name['multiplier']._options = None
  _QUERYMARKETATOMICEXECUTIONFEEMULTIPLIERRESPONSE.fields_by_name['multiplier']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _QUERY.methods_by_name['QueryExchangeParams']._options = None
  _QUERY.methods_by_name['QueryExchangeParams']._serialized_options = b'\202\323\344\223\002,\022*/injective/exchange/v1beta1/exchangeParams'
  _QUERY.methods_by_name['SubaccountDeposits']._options = None
  _QUERY.methods_by_name['SubaccountDeposits']._serialized_options = b'\202\323\344\223\0029\0227/injective/exchange/v1beta1/exchange/subaccountDeposits'
  _QUERY.methods_by_name['SubaccountDeposit']._options = None
  _QUERY.methods_by_name['SubaccountDeposit']._serialized_options = b'\202\323\344\223\0028\0226/injective/exchange/v1beta1/exchange/subaccountDeposit'
  _QUERY.methods_by_name['ExchangeBalances']._options = None
  _QUERY.methods_by_name['ExchangeBalances']._serialized_options = b'\202\323\344\223\0027\0225/injective/exchange/v1beta1/exchange/exchangeBalances'
  _QUERY.methods_by_name['AggregateVolume']._options = None
  _QUERY.methods_by_name['AggregateVolume']._serialized_options = b'\202\323\344\223\002@\022>/injective/exchange/v1beta1/exchange/aggregateVolume/{account}'
  _QUERY.methods_by_name['AggregateVolumes']._options = None
  _QUERY.methods_by_name['AggregateVolumes']._serialized_options = b'\202\323\344\223\0027\0225/injective/exchange/v1beta1/exchange/aggregateVolumes'
  _QUERY.methods_by_name['AggregateMarketVolume']._options = None
  _QUERY.methods_by_name['AggregateMarketVolume']._serialized_options = b'\202\323\344\223\002H\022F/injective/exchange/v1beta1/exchange/aggregateMarketVolume/{market_id}'
  _QUERY.methods_by_name['AggregateMarketVolumes']._options = None
  _QUERY.methods_by_name['AggregateMarketVolumes']._serialized_options = b'\202\323\344\223\002=\022;/injective/exchange/v1beta1/exchange/aggregateMarketVolumes'
  _QUERY.methods_by_name['DenomDecimal']._options = None
  _QUERY.methods_by_name['DenomDecimal']._serialized_options = b'\202\323\344\223\002<\022:/injective/exchange/v1beta1/exchange/denom_decimal/{denom}'
  _QUERY.methods_by_name['DenomDecimals']._options = None
  _QUERY.methods_by_name['DenomDecimals']._serialized_options = b'\202\323\344\223\0025\0223/injective/exchange/v1beta1/exchange/denom_decimals'
  _QUERY.methods_by_name['SpotMarkets']._options = None
  _QUERY.methods_by_name['SpotMarkets']._serialized_options = b'\202\323\344\223\002*\022(/injective/exchange/v1beta1/spot/markets'
  _QUERY.methods_by_name['SpotMarket']._options = None
  _QUERY.methods_by_name['SpotMarket']._serialized_options = b'\202\323\344\223\0026\0224/injective/exchange/v1beta1/spot/markets/{market_id}'
  _QUERY.methods_by_name['FullSpotMarkets']._options = None
  _QUERY.methods_by_name['FullSpotMarkets']._serialized_options = b'\202\323\344\223\002/\022-/injective/exchange/v1beta1/spot/full_markets'
  _QUERY.methods_by_name['FullSpotMarket']._options = None
  _QUERY.methods_by_name['FullSpotMarket']._serialized_options = b'\202\323\344\223\002:\0228/injective/exchange/v1beta1/spot/full_market/{market_id}'
  _QUERY.methods_by_name['SpotOrderbook']._options = None
  _QUERY.methods_by_name['SpotOrderbook']._serialized_options = b'\202\323\344\223\0028\0226/injective/exchange/v1beta1/spot/orderbook/{market_id}'
  _QUERY.methods_by_name['TraderSpotOrders']._options = None
  _QUERY.methods_by_name['TraderSpotOrders']._serialized_options = b'\202\323\344\223\002E\022C/injective/exchange/v1beta1/spot/orders/{market_id}/{subaccount_id}'
  _QUERY.methods_by_name['AccountAddressSpotOrders']._options = None
  _QUERY.methods_by_name['AccountAddressSpotOrders']._serialized_options = b'\202\323\344\223\002O\022M/injective/exchange/v1beta1/spot/orders/{market_id}/account/{account_address}'
  _QUERY.methods_by_name['SpotOrdersByHashes']._options = None
  _QUERY.methods_by_name['SpotOrdersByHashes']._serialized_options = b'\202\323\344\223\002O\022M/injective/exchange/v1beta1/spot/orders_by_hashes/{market_id}/{subaccount_id}'
  _QUERY.methods_by_name['SubaccountOrders']._options = None
  _QUERY.methods_by_name['SubaccountOrders']._serialized_options = b'\202\323\344\223\0024\0222/injective/exchange/v1beta1/orders/{subaccount_id}'
  _QUERY.methods_by_name['TraderSpotTransientOrders']._options = None
  _QUERY.methods_by_name['TraderSpotTransientOrders']._serialized_options = b'\202\323\344\223\002O\022M/injective/exchange/v1beta1/spot/transient_orders/{market_id}/{subaccount_id}'
  _QUERY.methods_by_name['SpotMidPriceAndTOB']._options = None
  _QUERY.methods_by_name['SpotMidPriceAndTOB']._serialized_options = b'\202\323\344\223\002@\022>/injective/exchange/v1beta1/spot/mid_price_and_tob/{market_id}'
  _QUERY.methods_by_name['DerivativeMidPriceAndTOB']._options = None
  _QUERY.methods_by_name['DerivativeMidPriceAndTOB']._serialized_options = b'\202\323\344\223\002F\022D/injective/exchange/v1beta1/derivative/mid_price_and_tob/{market_id}'
  _QUERY.methods_by_name['DerivativeOrderbook']._options = None
  _QUERY.methods_by_name['DerivativeOrderbook']._serialized_options = b'\202\323\344\223\002>\022</injective/exchange/v1beta1/derivative/orderbook/{market_id}'
  _QUERY.methods_by_name['TraderDerivativeOrders']._options = None
  _QUERY.methods_by_name['TraderDerivativeOrders']._serialized_options = b'\202\323\344\223\002K\022I/injective/exchange/v1beta1/derivative/orders/{market_id}/{subaccount_id}'
  _QUERY.methods_by_name['AccountAddressDerivativeOrders']._options = None
  _QUERY.methods_by_name['AccountAddressDerivativeOrders']._serialized_options = b'\202\323\344\223\002U\022S/injective/exchange/v1beta1/derivative/orders/{market_id}/account/{account_address}'
  _QUERY.methods_by_name['DerivativeOrdersByHashes']._options = None
  _QUERY.methods_by_name['DerivativeOrdersByHashes']._serialized_options = b'\202\323\344\223\002U\022S/injective/exchange/v1beta1/derivative/orders_by_hashes/{market_id}/{subaccount_id}'
  _QUERY.methods_by_name['TraderDerivativeTransientOrders']._options = None
  _QUERY.methods_by_name['TraderDerivativeTransientOrders']._serialized_options = b'\202\323\344\223\002U\022S/injective/exchange/v1beta1/derivative/transient_orders/{market_id}/{subaccount_id}'
  _QUERY.methods_by_name['DerivativeMarkets']._options = None
  _QUERY.methods_by_name['DerivativeMarkets']._serialized_options = b'\202\323\344\223\0020\022./injective/exchange/v1beta1/derivative/markets'
  _QUERY.methods_by_name['DerivativeMarket']._options = None
  _QUERY.methods_by_name['DerivativeMarket']._serialized_options = b'\202\323\344\223\002<\022:/injective/exchange/v1beta1/derivative/markets/{market_id}'
  _QUERY.methods_by_name['DerivativeMarketAddress']._options = None
  _QUERY.methods_by_name['DerivativeMarketAddress']._serialized_options = b'\202\323\344\223\002C\022A/injective/exchange/v1beta1/derivative/market_address/{market_id}'
  _QUERY.methods_by_name['SubaccountTradeNonce']._options = None
  _QUERY.methods_by_name['SubaccountTradeNonce']._serialized_options = b'\202\323\344\223\0026\0224/injective/exchange/v1beta1/exchange/{subaccount_id}'
  _QUERY.methods_by_name['ExchangeModuleState']._options = None
  _QUERY.methods_by_name['ExchangeModuleState']._serialized_options = b'\202\323\344\223\002*\022(/injective/exchange/v1beta1/module_state'
  _QUERY.methods_by_name['Positions']._options = None
  _QUERY.methods_by_name['Positions']._serialized_options = b'\202\323\344\223\002\'\022%/injective/exchange/v1beta1/positions'
  _QUERY.methods_by_name['SubaccountPositions']._options = None
  _QUERY.methods_by_name['SubaccountPositions']._serialized_options = b'\202\323\344\223\0027\0225/injective/exchange/v1beta1/positions/{subaccount_id}'
  _QUERY.methods_by_name['SubaccountPositionInMarket']._options = None
  _QUERY.methods_by_name['SubaccountPositionInMarket']._serialized_options = b'\202\323\344\223\002C\022A/injective/exchange/v1beta1/positions/{subaccount_id}/{market_id}'
  _QUERY.methods_by_name['SubaccountEffectivePositionInMarket']._options = None
  _QUERY.methods_by_name['SubaccountEffectivePositionInMarket']._serialized_options = b'\202\323\344\223\002M\022K/injective/exchange/v1beta1/effective_positions/{subaccount_id}/{market_id}'
  _QUERY.methods_by_name['PerpetualMarketInfo']._options = None
  _QUERY.methods_by_name['PerpetualMarketInfo']._serialized_options = b'\202\323\344\223\002?\022=/injective/exchange/v1beta1/perpetual_market_info/{market_id}'
  _QUERY.methods_by_name['ExpiryFuturesMarketInfo']._options = None
  _QUERY.methods_by_name['ExpiryFuturesMarketInfo']._serialized_options = b'\202\323\344\223\002<\022:/injective/exchange/v1beta1/expiry_market_info/{market_id}'
  _QUERY.methods_by_name['PerpetualMarketFunding']._options = None
  _QUERY.methods_by_name['PerpetualMarketFunding']._serialized_options = b'\202\323\344\223\002B\022@/injective/exchange/v1beta1/perpetual_market_funding/{market_id}'
  _QUERY.methods_by_name['SubaccountOrderMetadata']._options = None
  _QUERY.methods_by_name['SubaccountOrderMetadata']._serialized_options = b'\202\323\344\223\002<\022:/injective/exchange/v1beta1/order_metadata/{subaccount_id}'
  _QUERY.methods_by_name['TradeRewardPoints']._options = None
  _QUERY.methods_by_name['TradeRewardPoints']._serialized_options = b'\202\323\344\223\0021\022//injective/exchange/v1beta1/trade_reward_points'
  _QUERY.methods_by_name['PendingTradeRewardPoints']._options = None
  _QUERY.methods_by_name['PendingTradeRewardPoints']._serialized_options = b'\202\323\344\223\0029\0227/injective/exchange/v1beta1/pending_trade_reward_points'
  _QUERY.methods_by_name['TradeRewardCampaign']._options = None
  _QUERY.methods_by_name['TradeRewardCampaign']._serialized_options = b'\202\323\344\223\0023\0221/injective/exchange/v1beta1/trade_reward_campaign'
  _QUERY.methods_by_name['FeeDiscountAccountInfo']._options = None
  _QUERY.methods_by_name['FeeDiscountAccountInfo']._serialized_options = b'\202\323\344\223\002A\022?/injective/exchange/v1beta1/fee_discount_account_info/{account}'
  _QUERY.methods_by_name['FeeDiscountSchedule']._options = None
  _QUERY.methods_by_name['FeeDiscountSchedule']._serialized_options = b'\202\323\344\223\0023\0221/injective/exchange/v1beta1/fee_discount_schedule'
  _QUERY.methods_by_name['BalanceMismatches']._options = None
  _QUERY.methods_by_name['BalanceMismatches']._serialized_options = b'\202\323\344\223\002>\022</injective/exchange/v1beta1/balance_mismatches/{dust_factor}'
  _QUERY.methods_by_name['BalanceWithBalanceHolds']._options = None
  _QUERY.methods_by_name['BalanceWithBalanceHolds']._serialized_options = b'\202\323\344\223\0029\0227/injective/exchange/v1beta1/balances_with_balance_holds'
  _QUERY.methods_by_name['FeeDiscountTierStatistics']._options = None
  _QUERY.methods_by_name['FeeDiscountTierStatistics']._serialized_options = b'\202\323\344\223\0025\0223/injective/exchange/v1beta1/fee_discount_tier_stats'
  _QUERY.methods_by_name['MitoVaultInfos']._options = None
  _QUERY.methods_by_name['MitoVaultInfos']._serialized_options = b'\202\323\344\223\002.\022,/injective/exchange/v1beta1/mito_vault_infos'
  _QUERY.methods_by_name['QueryMarketIDFromVault']._options = None
  _QUERY.methods_by_name['QueryMarketIDFromVault']._serialized_options = b'\202\323\344\223\002=\022;/injective/exchange/v1beta1/vault_market_id/{vault_address}'
  _QUERY.methods_by_name['HistoricalTradeRecords']._options = None
  _QUERY.methods_by_name['HistoricalTradeRecords']._serialized_options = b'\202\323\344\223\0026\0224/injective/exchange/v1beta1/historical_trade_records'
  _QUERY.methods_by_name['IsOptedOutOfRewards']._options = None
  _QUERY.methods_by_name['IsOptedOutOfRewards']._serialized_options = b'\202\323\344\223\002?\022=/injective/exchange/v1beta1/is_opted_out_of_rewards/{account}'
  _QUERY.methods_by_name['OptedOutOfRewardsAccounts']._options = None
  _QUERY.methods_by_name['OptedOutOfRewardsAccounts']._serialized_options = b'\202\323\344\223\002;\0229/injective/exchange/v1beta1/opted_out_of_rewards_accounts'
  _QUERY.methods_by_name['MarketVolatility']._options = None
  _QUERY.methods_by_name['MarketVolatility']._serialized_options = b'\202\323\344\223\002;\0229/injective/exchange/v1beta1/market_volatility/{market_id}'
  _QUERY.methods_by_name['BinaryOptionsMarkets']._options = None
  _QUERY.methods_by_name['BinaryOptionsMarkets']._serialized_options = b'\202\323\344\223\0024\0222/injective/exchange/v1beta1/binary_options/markets'
  _QUERY.methods_by_name['TraderDerivativeConditionalOrders']._options = None
  _QUERY.methods_by_name['TraderDerivativeConditionalOrders']._serialized_options = b'\202\323\344\223\002W\022U/injective/exchange/v1beta1/derivative/orders/conditional/{market_id}/{subaccount_id}'
  _QUERY.methods_by_name['MarketAtomicExecutionFeeMultiplier']._options = None
  _QUERY.methods_by_name['MarketAtomicExecutionFeeMultiplier']._serialized_options = b'\202\323\344\223\0029\0227/injective/exchange/v1beta1/atomic_order_fee_multiplier'
  _globals['_ORDERSIDE']._serialized_start=14456
  _globals['_ORDERSIDE']._serialized_end=14508
  _globals['_CANCELLATIONSTRATEGY']._serialized_start=14510
  _globals['_CANCELLATIONSTRATEGY']._serialized_end=14596
  _globals['_SUBACCOUNT']._serialized_start=246
  _globals['_SUBACCOUNT']._serialized_end=300
  _globals['_QUERYSUBACCOUNTORDERSREQUEST']._serialized_start=302
  _globals['_QUERYSUBACCOUNTORDERSREQUEST']._serialized_end=374
  _globals['_QUERYSUBACCOUNTORDERSRESPONSE']._serialized_start=377
  _globals['_QUERYSUBACCOUNTORDERSRESPONSE']._serialized_end=547
  _globals['_SUBACCOUNTORDERBOOKMETADATAWITHMARKET']._serialized_start=550
  _globals['_SUBACCOUNTORDERBOOKMETADATAWITHMARKET']._serialized_end=698
  _globals['_QUERYEXCHANGEPARAMSREQUEST']._serialized_start=700
  _globals['_QUERYEXCHANGEPARAMSREQUEST']._serialized_end=728
  _globals['_QUERYEXCHANGEPARAMSRESPONSE']._serialized_start=730
  _globals['_QUERYEXCHANGEPARAMSRESPONSE']._serialized_end=817
  _globals['_QUERYSUBACCOUNTDEPOSITSREQUEST']._serialized_start=819
  _globals['_QUERYSUBACCOUNTDEPOSITSREQUEST']._serialized_end=940
  _globals['_QUERYSUBACCOUNTDEPOSITSRESPONSE']._serialized_start=943
  _globals['_QUERYSUBACCOUNTDEPOSITSRESPONSE']._serialized_end=1155
  _globals['_QUERYSUBACCOUNTDEPOSITSRESPONSE_DEPOSITSENTRY']._serialized_start=1071
  _globals['_QUERYSUBACCOUNTDEPOSITSRESPONSE_DEPOSITSENTRY']._serialized_end=1155
  _globals['_QUERYEXCHANGEBALANCESREQUEST']._serialized_start=1157
  _globals['_QUERYEXCHANGEBALANCESREQUEST']._serialized_end=1187
  _globals['_QUERYEXCHANGEBALANCESRESPONSE']._serialized_start=1189
  _globals['_QUERYEXCHANGEBALANCESRESPONSE']._serialized_end=1281
  _globals['_QUERYAGGREGATEVOLUMEREQUEST']._serialized_start=1283
  _globals['_QUERYAGGREGATEVOLUMEREQUEST']._serialized_end=1329
  _globals['_QUERYAGGREGATEVOLUMERESPONSE']._serialized_start=1331
  _globals['_QUERYAGGREGATEVOLUMERESPONSE']._serialized_end=1430
  _globals['_QUERYAGGREGATEVOLUMESREQUEST']._serialized_start=1432
  _globals['_QUERYAGGREGATEVOLUMESREQUEST']._serialized_end=1500
  _globals['_QUERYAGGREGATEVOLUMESRESPONSE']._serialized_start=1503
  _globals['_QUERYAGGREGATEVOLUMESRESPONSE']._serialized_end=1703
  _globals['_QUERYAGGREGATEMARKETVOLUMEREQUEST']._serialized_start=1705
  _globals['_QUERYAGGREGATEMARKETVOLUMEREQUEST']._serialized_end=1759
  _globals['_QUERYAGGREGATEMARKETVOLUMERESPONSE']._serialized_start=1761
  _globals['_QUERYAGGREGATEMARKETVOLUMERESPONSE']._serialized_end=1861
  _globals['_QUERYDENOMDECIMALREQUEST']._serialized_start=1863
  _globals['_QUERYDENOMDECIMALREQUEST']._serialized_end=1904
  _globals['_QUERYDENOMDECIMALRESPONSE']._serialized_start=1906
  _globals['_QUERYDENOMDECIMALRESPONSE']._serialized_end=1950
  _globals['_QUERYDENOMDECIMALSREQUEST']._serialized_start=1952
  _globals['_QUERYDENOMDECIMALSREQUEST']._serialized_end=1995
  _globals['_QUERYDENOMDECIMALSRESPONSE']._serialized_start=1997
  _globals['_QUERYDENOMDECIMALSRESPONSE']._serialized_end=2098
  _globals['_QUERYAGGREGATEMARKETVOLUMESREQUEST']._serialized_start=2100
  _globals['_QUERYAGGREGATEMARKETVOLUMESREQUEST']._serialized_end=2156
  _globals['_QUERYAGGREGATEMARKETVOLUMESRESPONSE']._serialized_start=2158
  _globals['_QUERYAGGREGATEMARKETVOLUMESRESPONSE']._serialized_end=2254
  _globals['_QUERYSUBACCOUNTDEPOSITREQUEST']._serialized_start=2256
  _globals['_QUERYSUBACCOUNTDEPOSITREQUEST']._serialized_end=2325
  _globals['_QUERYSUBACCOUNTDEPOSITRESPONSE']._serialized_start=2327
  _globals['_QUERYSUBACCOUNTDEPOSITRESPONSE']._serialized_end=2414
  _globals['_QUERYSPOTMARKETSREQUEST']._serialized_start=2416
  _globals['_QUERYSPOTMARKETSREQUEST']._serialized_end=2477
  _globals['_QUERYSPOTMARKETSRESPONSE']._serialized_start=2479
  _globals['_QUERYSPOTMARKETSRESPONSE']._serialized_end=2562
  _globals['_QUERYSPOTMARKETREQUEST']._serialized_start=2564
  _globals['_QUERYSPOTMARKETREQUEST']._serialized_end=2607
  _globals['_QUERYSPOTMARKETRESPONSE']._serialized_start=2609
  _globals['_QUERYSPOTMARKETRESPONSE']._serialized_end=2690
  _globals['_QUERYSPOTORDERBOOKREQUEST']._serialized_start=2693
  _globals['_QUERYSPOTORDERBOOKREQUEST']._serialized_end=2979
  _globals['_QUERYSPOTORDERBOOKRESPONSE']._serialized_start=2982
  _globals['_QUERYSPOTORDERBOOKRESPONSE']._serialized_end=3133
  _globals['_FULLSPOTMARKET']._serialized_start=3136
  _globals['_FULLSPOTMARKET']._serialized_end=3285
  _globals['_QUERYFULLSPOTMARKETSREQUEST']._serialized_start=3287
  _globals['_QUERYFULLSPOTMARKETSREQUEST']._serialized_end=3384
  _globals['_QUERYFULLSPOTMARKETSRESPONSE']._serialized_start=3386
  _globals['_QUERYFULLSPOTMARKETSRESPONSE']._serialized_end=3477
  _globals['_QUERYFULLSPOTMARKETREQUEST']._serialized_start=3479
  _globals['_QUERYFULLSPOTMARKETREQUEST']._serialized_end=3558
  _globals['_QUERYFULLSPOTMARKETRESPONSE']._serialized_start=3560
  _globals['_QUERYFULLSPOTMARKETRESPONSE']._serialized_end=3649
  _globals['_QUERYSPOTORDERSBYHASHESREQUEST']._serialized_start=3651
  _globals['_QUERYSPOTORDERSBYHASHESREQUEST']._serialized_end=3747
  _globals['_QUERYSPOTORDERSBYHASHESRESPONSE']._serialized_start=3749
  _globals['_QUERYSPOTORDERSBYHASHESRESPONSE']._serialized_end=3849
  _globals['_QUERYTRADERSPOTORDERSREQUEST']._serialized_start=3851
  _globals['_QUERYTRADERSPOTORDERSREQUEST']._serialized_end=3923
  _globals['_QUERYACCOUNTADDRESSSPOTORDERSREQUEST']._serialized_start=3925
  _globals['_QUERYACCOUNTADDRESSSPOTORDERSREQUEST']._serialized_end=4007
  _globals['_TRIMMEDSPOTLIMITORDER']._serialized_start=4010
  _globals['_TRIMMEDSPOTLIMITORDER']._serialized_end=4263
  _globals['_QUERYTRADERSPOTORDERSRESPONSE']._serialized_start=4265
  _globals['_QUERYTRADERSPOTORDERSRESPONSE']._serialized_end=4363
  _globals['_QUERYACCOUNTADDRESSSPOTORDERSRESPONSE']._serialized_start=4365
  _globals['_QUERYACCOUNTADDRESSSPOTORDERSRESPONSE']._serialized_end=4471
  _globals['_QUERYSPOTMIDPRICEANDTOBREQUEST']._serialized_start=4473
  _globals['_QUERYSPOTMIDPRICEANDTOBREQUEST']._serialized_end=4524
  _globals['_QUERYSPOTMIDPRICEANDTOBRESPONSE']._serialized_start=4527
  _globals['_QUERYSPOTMIDPRICEANDTOBRESPONSE']._serialized_end=4772
  _globals['_QUERYDERIVATIVEMIDPRICEANDTOBREQUEST']._serialized_start=4774
  _globals['_QUERYDERIVATIVEMIDPRICEANDTOBREQUEST']._serialized_end=4831
  _globals['_QUERYDERIVATIVEMIDPRICEANDTOBRESPONSE']._serialized_start=4834
  _globals['_QUERYDERIVATIVEMIDPRICEANDTOBRESPONSE']._serialized_end=5085
  _globals['_QUERYDERIVATIVEORDERBOOKREQUEST']._serialized_start=5088
  _globals['_QUERYDERIVATIVEORDERBOOKREQUEST']._serialized_end=5238
  _globals['_QUERYDERIVATIVEORDERBOOKRESPONSE']._serialized_start=5241
  _globals['_QUERYDERIVATIVEORDERBOOKRESPONSE']._serialized_end=5398
  _globals['_QUERYTRADERSPOTORDERSTOCANCELUPTOAMOUNTREQUEST']._serialized_start=5401
  _globals['_QUERYTRADERSPOTORDERSTOCANCELUPTOAMOUNTREQUEST']._serialized_end=5771
  _globals['_QUERYTRADERDERIVATIVEORDERSTOCANCELUPTOAMOUNTREQUEST']._serialized_start=5774
  _globals['_QUERYTRADERDERIVATIVEORDERSTOCANCELUPTOAMOUNTREQUEST']._serialized_end=6081
  _globals['_QUERYTRADERDERIVATIVEORDERSREQUEST']._serialized_start=6083
  _globals['_QUERYTRADERDERIVATIVEORDERSREQUEST']._serialized_end=6161
  _globals['_QUERYACCOUNTADDRESSDERIVATIVEORDERSREQUEST']._serialized_start=6163
  _globals['_QUERYACCOUNTADDRESSDERIVATIVEORDERSREQUEST']._serialized_end=6251
  _globals['_TRIMMEDDERIVATIVELIMITORDER']._serialized_start=6254
  _globals['_TRIMMEDDERIVATIVELIMITORDER']._serialized_end=6588
  _globals['_QUERYTRADERDERIVATIVEORDERSRESPONSE']._serialized_start=6590
  _globals['_QUERYTRADERDERIVATIVEORDERSRESPONSE']._serialized_end=6700
  _globals['_QUERYACCOUNTADDRESSDERIVATIVEORDERSRESPONSE']._serialized_start=6702
  _globals['_QUERYACCOUNTADDRESSDERIVATIVEORDERSRESPONSE']._serialized_end=6820
  _globals['_QUERYDERIVATIVEORDERSBYHASHESREQUEST']._serialized_start=6822
  _globals['_QUERYDERIVATIVEORDERSBYHASHESREQUEST']._serialized_end=6924
  _globals['_QUERYDERIVATIVEORDERSBYHASHESRESPONSE']._serialized_start=6926
  _globals['_QUERYDERIVATIVEORDERSBYHASHESRESPONSE']._serialized_end=7038
  _globals['_QUERYDERIVATIVEMARKETSREQUEST']._serialized_start=7040
  _globals['_QUERYDERIVATIVEMARKETSREQUEST']._serialized_end=7139
  _globals['_PRICELEVEL']._serialized_start=7142
  _globals['_PRICELEVEL']._serialized_end=7283
  _globals['_PERPETUALMARKETSTATE']._serialized_start=7286
  _globals['_PERPETUALMARKETSTATE']._serialized_end=7452
  _globals['_FULLDERIVATIVEMARKET']._serialized_start=7455
  _globals['_FULLDERIVATIVEMARKET']._serialized_end=7845
  _globals['_QUERYDERIVATIVEMARKETSRESPONSE']._serialized_start=7847
  _globals['_QUERYDERIVATIVEMARKETSRESPONSE']._serialized_end=7946
  _globals['_QUERYDERIVATIVEMARKETREQUEST']._serialized_start=7948
  _globals['_QUERYDERIVATIVEMARKETREQUEST']._serialized_end=7997
  _globals['_QUERYDERIVATIVEMARKETRESPONSE']._serialized_start=7999
  _globals['_QUERYDERIVATIVEMARKETRESPONSE']._serialized_end=8096
  _globals['_QUERYDERIVATIVEMARKETADDRESSREQUEST']._serialized_start=8098
  _globals['_QUERYDERIVATIVEMARKETADDRESSREQUEST']._serialized_end=8154
  _globals['_QUERYDERIVATIVEMARKETADDRESSRESPONSE']._serialized_start=8156
  _globals['_QUERYDERIVATIVEMARKETADDRESSRESPONSE']._serialized_end=8234
  _globals['_QUERYSUBACCOUNTTRADENONCEREQUEST']._serialized_start=8236
  _globals['_QUERYSUBACCOUNTTRADENONCEREQUEST']._serialized_end=8293
  _globals['_QUERYSUBACCOUNTPOSITIONSREQUEST']._serialized_start=8295
  _globals['_QUERYSUBACCOUNTPOSITIONSREQUEST']._serialized_end=8351
  _globals['_QUERYSUBACCOUNTPOSITIONINMARKETREQUEST']._serialized_start=8353
  _globals['_QUERYSUBACCOUNTPOSITIONINMARKETREQUEST']._serialized_end=8435
  _globals['_QUERYSUBACCOUNTEFFECTIVEPOSITIONINMARKETREQUEST']._serialized_start=8437
  _globals['_QUERYSUBACCOUNTEFFECTIVEPOSITIONINMARKETREQUEST']._serialized_end=8528
  _globals['_QUERYSUBACCOUNTORDERMETADATAREQUEST']._serialized_start=8530
  _globals['_QUERYSUBACCOUNTORDERMETADATAREQUEST']._serialized_end=8590
  _globals['_QUERYSUBACCOUNTPOSITIONSRESPONSE']._serialized_start=8592
  _globals['_QUERYSUBACCOUNTPOSITIONSRESPONSE']._serialized_end=8695
  _globals['_QUERYSUBACCOUNTPOSITIONINMARKETRESPONSE']._serialized_start=8697
  _globals['_QUERYSUBACCOUNTPOSITIONINMARKETRESPONSE']._serialized_end=8797
  _globals['_EFFECTIVEPOSITION']._serialized_start=8800
  _globals['_EFFECTIVEPOSITION']._serialized_end=9045
  _globals['_QUERYSUBACCOUNTEFFECTIVEPOSITIONINMARKETRESPONSE']._serialized_start=9047
  _globals['_QUERYSUBACCOUNTEFFECTIVEPOSITIONINMARKETRESPONSE']._serialized_end=9165
  _globals['_QUERYPERPETUALMARKETINFOREQUEST']._serialized_start=9167
  _globals['_QUERYPERPETUALMARKETINFOREQUEST']._serialized_end=9219
  _globals['_QUERYPERPETUALMARKETINFORESPONSE']._serialized_start=9221
  _globals['_QUERYPERPETUALMARKETINFORESPONSE']._serialized_end=9324
  _globals['_QUERYEXPIRYFUTURESMARKETINFOREQUEST']._serialized_start=9326
  _globals['_QUERYEXPIRYFUTURESMARKETINFOREQUEST']._serialized_end=9382
  _globals['_QUERYEXPIRYFUTURESMARKETINFORESPONSE']._serialized_start=9384
  _globals['_QUERYEXPIRYFUTURESMARKETINFORESPONSE']._serialized_end=9495
  _globals['_QUERYPERPETUALMARKETFUNDINGREQUEST']._serialized_start=9497
  _globals['_QUERYPERPETUALMARKETFUNDINGREQUEST']._serialized_end=9552
  _globals['_QUERYPERPETUALMARKETFUNDINGRESPONSE']._serialized_start=9554
  _globals['_QUERYPERPETUALMARKETFUNDINGRESPONSE']._serialized_end=9664
  _globals['_QUERYSUBACCOUNTORDERMETADATARESPONSE']._serialized_start=9667
  _globals['_QUERYSUBACCOUNTORDERMETADATARESPONSE']._serialized_end=9796
  _globals['_QUERYSUBACCOUNTTRADENONCERESPONSE']._serialized_start=9798
  _globals['_QUERYSUBACCOUNTTRADENONCERESPONSE']._serialized_end=9848
  _globals['_QUERYMODULESTATEREQUEST']._serialized_start=9850
  _globals['_QUERYMODULESTATEREQUEST']._serialized_end=9875
  _globals['_QUERYMODULESTATERESPONSE']._serialized_start=9877
  _globals['_QUERYMODULESTATERESPONSE']._serialized_end=9960
  _globals['_QUERYPOSITIONSREQUEST']._serialized_start=9962
  _globals['_QUERYPOSITIONSREQUEST']._serialized_end=9985
  _globals['_QUERYPOSITIONSRESPONSE']._serialized_start=9987
  _globals['_QUERYPOSITIONSRESPONSE']._serialized_end=10080
  _globals['_QUERYTRADEREWARDPOINTSREQUEST']._serialized_start=10082
  _globals['_QUERYTRADEREWARDPOINTSREQUEST']._serialized_end=10163
  _globals['_QUERYTRADEREWARDPOINTSRESPONSE']._serialized_start=10165
  _globals['_QUERYTRADEREWARDPOINTSRESPONSE']._serialized_end=10282
  _globals['_QUERYTRADEREWARDCAMPAIGNREQUEST']._serialized_start=10284
  _globals['_QUERYTRADEREWARDCAMPAIGNREQUEST']._serialized_end=10317
  _globals['_QUERYTRADEREWARDCAMPAIGNRESPONSE']._serialized_start=10320
  _globals['_QUERYTRADEREWARDCAMPAIGNRESPONSE']._serialized_end=10819
  _globals['_QUERYISOPTEDOUTOFREWARDSREQUEST']._serialized_start=10821
  _globals['_QUERYISOPTEDOUTOFREWARDSREQUEST']._serialized_end=10871
  _globals['_QUERYISOPTEDOUTOFREWARDSRESPONSE']._serialized_start=10873
  _globals['_QUERYISOPTEDOUTOFREWARDSRESPONSE']._serialized_end=10929
  _globals['_QUERYOPTEDOUTOFREWARDSACCOUNTSREQUEST']._serialized_start=10931
  _globals['_QUERYOPTEDOUTOFREWARDSACCOUNTSREQUEST']._serialized_end=10970
  _globals['_QUERYOPTEDOUTOFREWARDSACCOUNTSRESPONSE']._serialized_start=10972
  _globals['_QUERYOPTEDOUTOFREWARDSACCOUNTSRESPONSE']._serialized_end=11030
  _globals['_QUERYFEEDISCOUNTACCOUNTINFOREQUEST']._serialized_start=11032
  _globals['_QUERYFEEDISCOUNTACCOUNTINFOREQUEST']._serialized_end=11085
  _globals['_QUERYFEEDISCOUNTACCOUNTINFORESPONSE']._serialized_start=11088
  _globals['_QUERYFEEDISCOUNTACCOUNTINFORESPONSE']._serialized_end=11285
  _globals['_QUERYFEEDISCOUNTSCHEDULEREQUEST']._serialized_start=11287
  _globals['_QUERYFEEDISCOUNTSCHEDULEREQUEST']._serialized_end=11320
  _globals['_QUERYFEEDISCOUNTSCHEDULERESPONSE']._serialized_start=11322
  _globals['_QUERYFEEDISCOUNTSCHEDULERESPONSE']._serialized_end=11436
  _globals['_QUERYBALANCEMISMATCHESREQUEST']._serialized_start=11438
  _globals['_QUERYBALANCEMISMATCHESREQUEST']._serialized_end=11490
  _globals['_BALANCEMISMATCH']._serialized_start=11493
  _globals['_BALANCEMISMATCH']._serialized_end=11887
  _globals['_QUERYBALANCEMISMATCHESRESPONSE']._serialized_start=11889
  _globals['_QUERYBALANCEMISMATCHESRESPONSE']._serialized_end=11994
  _globals['_QUERYBALANCEWITHBALANCEHOLDSREQUEST']._serialized_start=11996
  _globals['_QUERYBALANCEWITHBALANCEHOLDSREQUEST']._serialized_end=12033
  _globals['_BALANCEWITHMARGINHOLD']._serialized_start=12036
  _globals['_BALANCEWITHMARGINHOLD']._serialized_end=12296
  _globals['_QUERYBALANCEWITHBALANCEHOLDSRESPONSE']._serialized_start=12298
  _globals['_QUERYBALANCEWITHBALANCEHOLDSRESPONSE']._serialized_end=12423
  _globals['_QUERYFEEDISCOUNTTIERSTATISTICSREQUEST']._serialized_start=12425
  _globals['_QUERYFEEDISCOUNTTIERSTATISTICSREQUEST']._serialized_end=12464
  _globals['_TIERSTATISTIC']._serialized_start=12466
  _globals['_TIERSTATISTIC']._serialized_end=12510
  _globals['_QUERYFEEDISCOUNTTIERSTATISTICSRESPONSE']._serialized_start=12512
  _globals['_QUERYFEEDISCOUNTTIERSTATISTICSRESPONSE']._serialized_end=12615
  _globals['_MITOVAULTINFOSREQUEST']._serialized_start=12617
  _globals['_MITOVAULTINFOSREQUEST']._serialized_end=12640
  _globals['_MITOVAULTINFOSRESPONSE']._serialized_start=12643
  _globals['_MITOVAULTINFOSRESPONSE']._serialized_end=12771
  _globals['_QUERYMARKETIDFROMVAULTREQUEST']._serialized_start=12773
  _globals['_QUERYMARKETIDFROMVAULTREQUEST']._serialized_end=12827
  _globals['_QUERYMARKETIDFROMVAULTRESPONSE']._serialized_start=12829
  _globals['_QUERYMARKETIDFROMVAULTRESPONSE']._serialized_end=12880
  _globals['_QUERYHISTORICALTRADERECORDSREQUEST']._serialized_start=12882
  _globals['_QUERYHISTORICALTRADERECORDSREQUEST']._serialized_end=12937
  _globals['_QUERYHISTORICALTRADERECORDSRESPONSE']._serialized_start=12939
  _globals['_QUERYHISTORICALTRADERECORDSRESPONSE']._serialized_end=13041
  _globals['_TRADEHISTORYOPTIONS']._serialized_start=13043
  _globals['_TRADEHISTORYOPTIONS']._serialized_end=13164
  _globals['_QUERYMARKETVOLATILITYREQUEST']._serialized_start=13167
  _globals['_QUERYMARKETVOLATILITYREQUEST']._serialized_end=13296
  _globals['_QUERYMARKETVOLATILITYRESPONSE']._serialized_start=13299
  _globals['_QUERYMARKETVOLATILITYRESPONSE']._serialized_end=13528
  _globals['_QUERYBINARYMARKETSREQUEST']._serialized_start=13530
  _globals['_QUERYBINARYMARKETSREQUEST']._serialized_end=13573
  _globals['_QUERYBINARYMARKETSRESPONSE']._serialized_start=13575
  _globals['_QUERYBINARYMARKETSRESPONSE']._serialized_end=13669
  _globals['_QUERYTRADERDERIVATIVECONDITIONALORDERSREQUEST']._serialized_start=13671
  _globals['_QUERYTRADERDERIVATIVECONDITIONALORDERSREQUEST']._serialized_end=13760
  _globals['_TRIMMEDDERIVATIVECONDITIONALORDER']._serialized_start=13763
  _globals['_TRIMMEDDERIVATIVECONDITIONALORDER']._serialized_end=14137
  _globals['_QUERYTRADERDERIVATIVECONDITIONALORDERSRESPONSE']._serialized_start=14139
  _globals['_QUERYTRADERDERIVATIVECONDITIONALORDERSRESPONSE']._serialized_end=14266
  _globals['_QUERYMARKETATOMICEXECUTIONFEEMULTIPLIERREQUEST']._serialized_start=14268
  _globals['_QUERYMARKETATOMICEXECUTIONFEEMULTIPLIERREQUEST']._serialized_end=14335
  _globals['_QUERYMARKETATOMICEXECUTIONFEEMULTIPLIERRESPONSE']._serialized_start=14337
  _globals['_QUERYMARKETATOMICEXECUTIONFEEMULTIPLIERRESPONSE']._serialized_end=14454
  _globals['_QUERY']._serialized_start=14599
  _globals['_QUERY']._serialized_end=26964
# @@protoc_insertion_point(module_scope)



from abc import ABC, abstractmethod

from google.protobuf import any_pb2

from pyinjective.proto.cosmos.authz.v1beta1 import tx_pb2 as cosmos_authz_tx_pb
from pyinjective.proto.cosmos.gov.v1beta1 import tx_pb2 as gov_tx_pb
from pyinjective.proto.cosmwasm.wasm.v1 import tx_pb2 as wasm_tx_pb
from pyinjective.proto.injective.exchange.v1beta1 import tx_pb2 as injective_exchange_tx_pb


class GasLimitEstimator(ABC):
    GENERAL_MESSAGE_GAS_LIMIT = 5_000
    BASIC_REFERENCE_GAS_LIMIT = 150_000

    @classmethod
    @abstractmethod
    def applies_to(cls, message: any_pb2.Any) -> bool:
        ...

    @classmethod
    def for_message(cls, message: any_pb2.Any):
        estimator_class = next(
            (
                estimator_subclass
                for estimator_subclass in cls.__subclasses__()
                if estimator_subclass.applies_to(message=message)
            ),
            None,
        )
        if estimator_class is None:
            estimator = DefaultGasLimitEstimator()
        else:
            estimator = estimator_class(message=message)

        return estimator

    @abstractmethod
    def gas_limit(self) -> int:
        ...

    @staticmethod
    def message_type(message: any_pb2.Any) -> str:
        if isinstance(message, any_pb2.Any):
            message_type = message.type_url
        else:
            message_type = message.DESCRIPTOR.full_name
        return message_type

    @abstractmethod
    def _message_class(self, message: any_pb2.Any):
        ...

    def _parsed_message(self, message: any_pb2.Any) -> any_pb2.Any:
        if isinstance(message, any_pb2.Any):
            parsed_message = self._message_class(message=message).FromString(message.value)
        else:
            parsed_message = message
        return parsed_message


class DefaultGasLimitEstimator(GasLimitEstimator):
    DEFAULT_GAS_LIMIT = 150_000

    @classmethod
    def applies_to(cls, message: any_pb2.Any) -> bool:
        return False

    def gas_limit(self) -> int:
        return self.DEFAULT_GAS_LIMIT

    def _message_class(self, message: any_pb2.Any):
        # This class should not try to convert messages
        raise NotImplementedError


class BatchCreateSpotLimitOrdersGasLimitEstimator(GasLimitEstimator):
    ORDER_GAS_LIMIT = 45_000

    def __init__(self, message: any_pb2.Any):
        self._message = self._parsed_message(message=message)

    @classmethod
    def applies_to(cls, message: any_pb2.Any):
        return cls.message_type(message=message).endswith("MsgBatchCreateSpotLimitOrders")

    def gas_limit(self) -> int:
        total = 0
        total += self.GENERAL_MESSAGE_GAS_LIMIT
        total += len(self._message.orders) * self.ORDER_GAS_LIMIT

        return total

    def _message_class(self, message: any_pb2.Any):
        return injective_exchange_tx_pb.MsgBatchCreateSpotLimitOrders


class BatchCancelSpotOrdersGasLimitEstimator(GasLimitEstimator):
    ORDER_GAS_LIMIT = 45_000

    def __init__(self, message: any_pb2.Any):
        self._message = self._parsed_message(message=message)

    @classmethod
    def applies_to(cls, message: any_pb2.Any):
        return cls.message_type(message=message).endswith("MsgBatchCancelSpotOrders")

    def gas_limit(self) -> int:
        total = 0
        total += self.GENERAL_MESSAGE_GAS_LIMIT
        total += len(self._message.data) * self.ORDER_GAS_LIMIT

        return total

    def _message_class(self, message: any_pb2.Any):
        return injective_exchange_tx_pb.MsgBatchCancelSpotOrders


class BatchCreateDerivativeLimitOrdersGasLimitEstimator(GasLimitEstimator):
    ORDER_GAS_LIMIT = 60_000

    def __init__(self, message: any_pb2.Any):
        self._message = self._parsed_message(message=message)

    @classmethod
    def applies_to(cls, message: any_pb2.Any):
        return cls.message_type(message=message).endswith("MsgBatchCreateDerivativeLimitOrders")

    def gas_limit(self) -> int:
        total = 0
        total += self.GENERAL_MESSAGE_GAS_LIMIT
        total += len(self._message.orders) * self.ORDER_GAS_LIMIT

        return total

    def _message_class(self, message: any_pb2.Any):
        return injective_exchange_tx_pb.MsgBatchCreateDerivativeLimitOrders


class BatchCancelDerivativeOrdersGasLimitEstimator(GasLimitEstimator):
    ORDER_GAS_LIMIT = 55_000

    def __init__(self, message: any_pb2.Any):
        self._message = self._parsed_message(message=message)

    @classmethod
    def applies_to(cls, message: any_pb2.Any):
        return cls.message_type(message=message).endswith("MsgBatchCancelDerivativeOrders")

    def gas_limit(self) -> int:
        total = 0
        total += self.GENERAL_MESSAGE_GAS_LIMIT
        total += len(self._message.data) * self.ORDER_GAS_LIMIT

        return total

    def _message_class(self, message: any_pb2.Any):
        return injective_exchange_tx_pb.MsgBatchCancelDerivativeOrders


class BatchUpdateOrdersGasLimitEstimator(GasLimitEstimator):
    SPOT_ORDER_CREATION_GAS_LIMIT = 40_000
    DERIVATIVE_ORDER_CREATION_GAS_LIMIT = 60_000
    SPOT_ORDER_CANCELATION_GAS_LIMIT = 45_000
    DERIVATIVE_ORDER_CANCELATION_GAS_LIMIT = 55_000
    CANCEL_ALL_SPOT_MARKET_GAS_LIMIT = 35_000
    CANCEL_ALL_DERIVATIVE_MARKET_GAS_LIMIT = 45_000
    MESSAGE_GAS_LIMIT = 10_000

    AVERAGE_CANCEL_ALL_AFFECTED_ORDERS = 20

    def __init__(self, message: any_pb2.Any):
        self._message = self._parsed_message(message=message)

    @classmethod
    def applies_to(cls, message: any_pb2.Any):
        return cls.message_type(message=message).endswith("MsgBatchUpdateOrders")

    def gas_limit(self) -> int:
        total = 0
        total += self.MESSAGE_GAS_LIMIT
        total += len(self._message.spot_orders_to_create) * self.SPOT_ORDER_CREATION_GAS_LIMIT
        total += len(self._message.derivative_orders_to_create) * self.DERIVATIVE_ORDER_CREATION_GAS_LIMIT
        total += len(self._message.binary_options_orders_to_create) * self.DERIVATIVE_ORDER_CREATION_GAS_LIMIT
        total += len(self._message.spot_orders_to_cancel) * self.SPOT_ORDER_CANCELATION_GAS_LIMIT
        total += len(self._message.derivative_orders_to_cancel) * self.DERIVATIVE_ORDER_CANCELATION_GAS_LIMIT
        total += len(self._message.binary_options_orders_to_cancel) * self.DERIVATIVE_ORDER_CANCELATION_GAS_LIMIT

        total += (
            len(self._message.spot_market_ids_to_cancel_all)
            * self.CANCEL_ALL_SPOT_MARKET_GAS_LIMIT
            * self.AVERAGE_CANCEL_ALL_AFFECTED_ORDERS
        )
        total += (
            len(self._message.derivative_market_ids_to_cancel_all)
            * self.CANCEL_ALL_DERIVATIVE_MARKET_GAS_LIMIT
            * self.AVERAGE_CANCEL_ALL_AFFECTED_ORDERS
        )
        total += (
            len(self._message.binary_options_market_ids_to_cancel_all)
            * self.CANCEL_ALL_DERIVATIVE_MARKET_GAS_LIMIT
            * self.AVERAGE_CANCEL_ALL_AFFECTED_ORDERS
        )

        return total

    def _message_class(self, message: any_pb2.Any):
        return injective_exchange_tx_pb.MsgBatchUpdateOrders


class ExecGasLimitEstimator(GasLimitEstimator):
    DEFAULT_GAS_LIMIT = 5_000

    def __init__(self, message: any_pb2.Any):
        self._message = self._parsed_message(message=message)

    @classmethod
    def applies_to(cls, message: any_pb2.Any) -> bool:
        return cls.message_type(message=message).endswith("MsgExec")

    def gas_limit(self) -> int:
        total = sum(
            [GasLimitEstimator.for_message(message=inner_message).gas_limit() for inner_message in self._message.msgs]
        )
        total += self.DEFAULT_GAS_LIMIT

        return total

    def _message_class(self, message: any_pb2.Any):
        return cosmos_authz_tx_pb.MsgExec


class PrivilegedExecuteContractGasLimitEstimator(GasLimitEstimator):
    def __init__(self, message: any_pb2.Any):
        self._message = self._parsed_message(message=message)

    @classmethod
    def applies_to(cls, message: any_pb2.Any) -> bool:
        return cls.message_type(message=message).endswith("MsgPrivilegedExecuteContract")

    def gas_limit(self) -> int:
        return self.BASIC_REFERENCE_GAS_LIMIT * 6

    def _message_class(self, message: any_pb2.Any):
        return injective_exchange_tx_pb.MsgPrivilegedExecuteContract


class ExecuteContractGasLimitEstimator(GasLimitEstimator):
    def __init__(self, message: any_pb2.Any):
        self._message = self._parsed_message(message=message)

    @classmethod
    def applies_to(cls, message: any_pb2.Any) -> bool:
        return cls.message_type(message=message).endswith("MsgExecuteContract")

    def gas_limit(self) -> int:
        return int(self.BASIC_REFERENCE_GAS_LIMIT * 2.5)

    def _message_class(self, message: any_pb2.Any):
        return wasm_tx_pb.MsgExecuteContract


class GeneralWasmGasLimitEstimator(GasLimitEstimator):
    def __init__(self, message: any_pb2.Any):
        self._message = self._parsed_message(message=message)

    @classmethod
    def applies_to(cls, message: any_pb2.Any) -> bool:
        return "wasm." in cls.message_type(message=message)

    def gas_limit(self) -> int:
        return int(self.BASIC_REFERENCE_GAS_LIMIT * 1.5)

    def _message_class(self, message: any_pb2.Any):
        return wasm_tx_pb.MsgInstantiateContract2


class GovernanceGasLimitEstimator(GasLimitEstimator):
    def __init__(self, message: any_pb2.Any):
        self._message = self._parsed_message(message=message)

    @classmethod
    def applies_to(cls, message: any_pb2.Any) -> bool:
        message_type = cls.message_type(message=message)
        return "gov." in message_type and (
            message_type.endswith("MsgDeposit") or message_type.endswith("MsgSubmitProposal")
        )

    def gas_limit(self) -> int:
        return int(self.BASIC_REFERENCE_GAS_LIMIT * 15)

    def _message_class(self, message: any_pb2.Any):
        if "MsgDeposit" in self.message_type(message=message):
            message_class = gov_tx_pb.MsgDeposit
        else:
            message_class = gov_tx_pb.MsgSubmitProposal
        return message_class


class GenericExchangeGasLimitEstimator(GasLimitEstimator):
    BASIC_REFERENCE_GAS_LIMIT = 100_000

    def __init__(self, message: any_pb2.Any):
        self._message = message

    @classmethod
    def applies_to(cls, message: any_pb2.Any) -> bool:
        message_type = cls.message_type(message=message)
        return "exchange." in message_type

    def gas_limit(self) -> int:
        return self.BASIC_REFERENCE_GAS_LIMIT

    def _message_class(self, message: any_pb2.Any):
        # This class applies to many different messages, but we don't need to transform from Any format
        raise NotImplementedError



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tendermint/crypto/proof.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dtendermint/crypto/proof.proto\x12\x11tendermint.crypto\x1a\x14gogoproto/gogo.proto\"G\n\x05Proof\x12\r\n\x05total\x18\x01 \x01(\x03\x12\r\n\x05index\x18\x02 \x01(\x03\x12\x11\n\tleaf_hash\x18\x03 \x01(\x0c\x12\r\n\x05\x61unts\x18\x04 \x03(\x0c\"?\n\x07ValueOp\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\'\n\x05proof\x18\x02 \x01(\x0b\x32\x18.tendermint.crypto.Proof\"6\n\x08\x44ominoOp\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05input\x18\x02 \x01(\t\x12\x0e\n\x06output\x18\x03 \x01(\t\"2\n\x07ProofOp\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\x0c\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\"9\n\x08ProofOps\x12-\n\x03ops\x18\x01 \x03(\x0b\x32\x1a.tendermint.crypto.ProofOpB\x04\xc8\xde\x1f\x00\x42\x36Z4github.com/cometbft/cometbft/proto/tendermint/cryptob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.crypto.proof_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z4github.com/cometbft/cometbft/proto/tendermint/crypto'
  _PROOFOPS.fields_by_name['ops']._options = None
  _PROOFOPS.fields_by_name['ops']._serialized_options = b'\310\336\037\000'
  _globals['_PROOF']._serialized_start=74
  _globals['_PROOF']._serialized_end=145
  _globals['_VALUEOP']._serialized_start=147
  _globals['_VALUEOP']._serialized_end=210
  _globals['_DOMINOOP']._serialized_start=212
  _globals['_DOMINOOP']._serialized_end=266
  _globals['_PROOFOP']._serialized_start=268
  _globals['_PROOFOP']._serialized_end=318
  _globals['_PROOFOPS']._serialized_start=320
  _globals['_PROOFOPS']._serialized_end=377
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/evidence/v1beta1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n cosmos/evidence/v1beta1/tx.proto\x12\x17\x63osmos.evidence.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x11\x61mino/amino.proto\"\xc7\x01\n\x11MsgSubmitEvidence\x12+\n\tsubmitter\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12L\n\x08\x65vidence\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyB$\xca\xb4- cosmos.evidence.v1beta1.Evidence:7\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\tsubmitter\x8a\xe7\xb0*\x1c\x63osmos-sdk/MsgSubmitEvidence\")\n\x19MsgSubmitEvidenceResponse\x12\x0c\n\x04hash\x18\x04 \x01(\x0c\x32~\n\x03Msg\x12p\n\x0eSubmitEvidence\x12*.cosmos.evidence.v1beta1.MsgSubmitEvidence\x1a\x32.cosmos.evidence.v1beta1.MsgSubmitEvidenceResponse\x1a\x05\x80\xe7\xb0*\x01\x42\x33Z-github.com/cosmos/cosmos-sdk/x/evidence/types\xa8\xe2\x1e\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.evidence.v1beta1.tx_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/cosmos/cosmos-sdk/x/evidence/types\250\342\036\001'
  _MSGSUBMITEVIDENCE.fields_by_name['submitter']._options = None
  _MSGSUBMITEVIDENCE.fields_by_name['submitter']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGSUBMITEVIDENCE.fields_by_name['evidence']._options = None
  _MSGSUBMITEVIDENCE.fields_by_name['evidence']._serialized_options = b'\312\264- cosmos.evidence.v1beta1.Evidence'
  _MSGSUBMITEVIDENCE._options = None
  _MSGSUBMITEVIDENCE._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\tsubmitter\212\347\260*\034cosmos-sdk/MsgSubmitEvidence'
  _MSG._options = None
  _MSG._serialized_options = b'\200\347\260*\001'
  _globals['_MSGSUBMITEVIDENCE']._serialized_start=182
  _globals['_MSGSUBMITEVIDENCE']._serialized_end=381
  _globals['_MSGSUBMITEVIDENCERESPONSE']._serialized_start=383
  _globals['_MSGSUBMITEVIDENCERESPONSE']._serialized_end=424
  _globals['_MSG']._serialized_start=426
  _globals['_MSG']._serialized_end=552
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/transfer/v1/transfer.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+ibc/applications/transfer/v1/transfer.proto\x12\x1cibc.applications.transfer.v1\x1a\x14gogoproto/gogo.proto\".\n\nDenomTrace\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x12\n\nbase_denom\x18\x02 \x01(\t\"l\n\x06Params\x12-\n\x0csend_enabled\x18\x01 \x01(\x08\x42\x17\xf2\xde\x1f\x13yaml:\"send_enabled\"\x12\x33\n\x0freceive_enabled\x18\x02 \x01(\x08\x42\x1a\xf2\xde\x1f\x16yaml:\"receive_enabled\"B9Z7github.com/cosmos/ibc-go/v7/modules/apps/transfer/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.transfer.v1.transfer_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z7github.com/cosmos/ibc-go/v7/modules/apps/transfer/types'
  _PARAMS.fields_by_name['send_enabled']._options = None
  _PARAMS.fields_by_name['send_enabled']._serialized_options = b'\362\336\037\023yaml:\"send_enabled\"'
  _PARAMS.fields_by_name['receive_enabled']._options = None
  _PARAMS.fields_by_name['receive_enabled']._serialized_options = b'\362\336\037\026yaml:\"receive_enabled\"'
  _globals['_DENOMTRACE']._serialized_start=99
  _globals['_DENOMTRACE']._serialized_end=145
  _globals['_PARAMS']._serialized_start=147
  _globals['_PARAMS']._serialized_end=255
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/bank/v1beta1/events.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n cosmos/bank/v1beta1/events.proto\x12\x13\x63osmos.bank.v1beta1\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x11\x61mino/amino.proto\"O\n\x10\x45ventSetBalances\x12;\n\x0f\x62\x61lance_updates\x18\x01 \x03(\x0b\x32\".cosmos.bank.v1beta1.BalanceUpdate\"|\n\rBalanceUpdate\x12\x0c\n\x04\x61\x64\x64r\x18\x01 \x01(\x0c\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\x0c\x12N\n\x03\x61mt\x18\x03 \x01(\tBA\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xd2\xb4-\ncosmos.Int\xa8\xe7\xb0*\x01\x42+Z)github.com/cosmos/cosmos-sdk/x/bank/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.bank.v1beta1.events_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z)github.com/cosmos/cosmos-sdk/x/bank/types'
  _BALANCEUPDATE.fields_by_name['amt']._options = None
  _BALANCEUPDATE.fields_by_name['amt']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\322\264-\ncosmos.Int\250\347\260*\001'
  _globals['_EVENTSETBALANCES']._serialized_start=125
  _globals['_EVENTSETBALANCES']._serialized_end=204
  _globals['_BALANCEUPDATE']._serialized_start=206
  _globals['_BALANCEUPDATE']._serialized_end=330
# @@protoc_insertion_point(module_scope)
